
from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any

class MeasurementScale():
    """
    The measurement scale for the document. See MeasurementScale (in the Properties table for the Document object.)Note: The MeasurementScale feature is available in the Extended Version only.
    """
    @property
    def PixelLength(self) -> int:
        """
        Read-write. The length in pixels this scale equates to.
        """
        ...

    @property
    def LogicalLength(self) -> float:
        """
        Read-write. The logical length this scale equates to.
        """
        ...

    @property
    def LogicalUnits(self) -> str:
        """
        Read-write. The logical units for this scale.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psgalleryconstraintype import PsGalleryConstrainType
    from .application import Application
    from .psgalleryfonttype import PsGalleryFontType

class GalleryImagesOptions():
    """
    Options that define the ImagesOptions property of the GalleryOptions object. See ‘GalleryOptions ’ on page 82.Tip: You can preserve default values for many GalleryImagesOptions properties by setting the GalleryOptions property PreserveAllMetadata to true or by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Border(self) -> int:
        """
        Read-write. The size (in pixels) of the border that separates images (0 - 99; default: 0).
        """
        ...

    @property
    def Caption(self) -> bool:
        """
        Read-write. Indication of whether to generate image captions. Default: false.
        """
        ...

    @property
    def Dimension(self) -> int:
        """
        Read-write. The resized image dimensions in pixels. Default: 350. Note:Valid only when ResizeImages = true. See ResizeImages.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The font to use for image captions. Default: 1.
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The font size for image captions (1 - 7; default: 3). Note:Valid only when Caption = true. See Caption.
        """
        ...

    @property
    def ImageQuality(self) -> int:
        """
        Read-write. The quality setting for a JPEG image (0 - 12; default: 5).
        """
        ...

    @property
    def IncludeCopyright(self) -> bool:
        """
        Read-write. Indication of whether to include copyright information in captions. Default: false. Note:Valid only when Caption = true. See Caption.
        """
        ...

    @property
    def IncludeCredits(self) -> bool:
        """
        Read-write. Indication of whether to include the credits in image captions. Default: false. Note:Valid only when Caption = true. See Caption.
        """
        ...

    @property
    def IncludeFilename(self) -> bool:
        """
        Read-write. Indication of whether to include the file name in image captions. Default: true. Note:Valid only when Caption = true. See Caption.
        """
        ...

    @property
    def IncludeTitle(self) -> bool:
        """
        Read-write. Indication of whether to include the title in image captions. Default: false. Note:Valid only when Caption = true. See Caption.
        """
        ...

    @property
    def NumericLinks(self) -> bool:
        """
        Read-write. Indication of whether to add numeric links. Default: true.
        """
        ...

    @property
    def ResizeConstraint(self) -> PsGalleryConstrainType:
        """
        Read-write. The image dimensions to constrain in the gallery image. Default: 3. Note:Valid only when ResizeImages = true. See ResizeImages.
        """
        ...

    @property
    def ResizeImages(self) -> bool:
        """
        Read-write. Indication of whether to automatically resize images for placement on the gallery pages. Default: true.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GalleryImagesOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .subpathinfo import SubPathInfo
    from .application import Application
    from .document import Document
    from .pathitem import PathItem

class PathItems():
    """
    The collection of PathItem objects in the document.Note: See ‘PathItem ’ on page 109 for information on PathItem objects.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of PathItem objects in the PathItems collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The PathItems object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PathItems object.
        """
        ...

    def Add(self, Name:str, EntirePath:List[SubPathInfo]) -> PathItem:
        """
        Creates a new PathItem object from the sub paths defined in the array provided in the EntirePath parameter. A new SubPathItem object is created for each SubPathInfo object provided in entirePath, and those SubPathItem objects are added to the SubPathItems collection of the returned PathItem.
        """
        ...

    def Index(self, ItemPtr:PathItem) -> int:
        """
        Gets the index of the PathIem into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> PathItem:
        """
        Gets a PathItem object from the PathItems collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all PathItem objects from the PathItems collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pscolorreductiontype import PsColorReductionType
    from .rgbcolor import RGBColor
    from .application import Application
    from .psdithertype import PsDitherType
    from .pssavedocumenttype import PsSaveDocumentType

class ExportOptionsSaveForWeb():
    """
    Options that can be specified when optimizing a document for the Web, or for devices. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Blur(self) -> float:
        """
        Read-write. Applies blur to the image to reduce artifacts. Default: 0.0.
        """
        ...

    @property
    def ColorReduction(self) -> PsColorReductionType:
        """
        Read-write. The color reduction algorithm. Default: 1 (psSelective).
        """
        ...

    @property
    def Colors(self) -> int:
        """
        Read-write. The number of colors in the palette. Default: 256.
        """
        ...

    @property
    def Dither(self) -> PsDitherType:
        """
        Read-write. The type of dither. Default: 2 (psDiffusion).
        """
        ...

    @property
    def DitherAmount(self) -> int:
        """
        Read-write. The amount of dither. Default: 100. Note:Valid only when Dither = 2. See Dither.
        """
        ...

    @property
    def Format(self) -> PsSaveDocumentType:
        """
        Read-write. The file format to use. Default: 3 (psCompuServeGIFSave).
        """
        ...

    @property
    def IncludeProfile(self) -> bool:
        """
        Read-write. Indicates whether to include the document’s embedded color profile. Default: false.
        """
        ...

    @property
    def Interlaced(self) -> bool:
        """
        Read-write. Indicates whether to download in multiple passes; progressive. Default: false.
        """
        ...

    @property
    def Lossy(self) -> int:
        """
        Read-write. The amount of lossiness allowed. Default: 0.
        """
        ...

    @property
    def MatteColor(self) -> RGBColor:
        """
        Read-write. The colors to blend transparent pixels against.
        """
        ...

    @property
    def Optimized(self) -> bool:
        """
        Read-write. Indicates whether to create smaller but less compatible files. Default: true. Note:Valid only when format = 6 (psJPEGSave). See Format.
        """
        ...

    @property
    def PNG8(self) -> bool:
        """
        Read-write. Indicates the number of bits; true = 8, false = 24. Default: true. Note:Valid only when format = 13 (psPNGSave). See Format.
        """
        ...

    @property
    def Quality(self) -> int:
        """
        Read-write. The quality of the produced image (0 - 100 as percentage; default: 60).
        """
        ...

    @property
    def Transparency(self) -> bool:
        """
        Read-write. Indicates transparent areas of the image should be included in the saved image. Default: true.
        """
        ...

    @property
    def TransparencyAmount(self) -> int:
        """
        Read-write. The amount of transparency dither. Default: 100. Note:Valid only if Transparency = true. See Transparency.
        """
        ...

    @property
    def TransparencyDither(self) -> PsDitherType:
        """
        Read-write. The transparency dither algorithm. Default: 1.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ExportOptionsSaveForWeb object.
        """
        ...

    @property
    def WebSnap(self) -> int:
        """
        Read-write. The tolerance amount within which to snap close colors to Web palette colors. Default: 0.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .document import Document

class LayerComp():
    """
    A snapshot of a state of the layers in a document (can be used to view different page layouts or compositions). 
    """
    @property
    def Appearance(self) -> bool:
        """
        Read-write. Indicates whether to use layer appearance (layer styles) settings.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Comment(self) -> str:
        """
        Read-write. A description of the layer comp.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The name of the layer comp.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-write. The LayerComp object's container.
        """
        ...

    @property
    def Position(self) -> bool:
        """
        Read-write. Indicates whether to use layer position.
        """
        ...

    @property
    def Selected(self) -> bool:
        """
        Read-only. Indicates whether the layer comp is currently selected.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced LayerComp object.
        """
        ...

    @property
    def Visibility(self) -> bool:
        """
        Read-write. Indicates whether to use layer visibility settings.
        """
        ...

    def Apply(self) -> None:
        """
        Applies the layer comp to the document.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes the LayerComp object.
        """
        ...

    def Recapture(self) -> None:
        """
        Recaptures the current layer state(s) for this layer comp.
        """
        ...

    def ResetfromComp(self) -> None:
        """
        Resets the layer comp state to the document state.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class CMYKColor():
    """
    The definition of a CMYK color. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Black(self) -> float:
        """
        Read-write. The black color value (as percent) (0.0 - 100.0).
        """
        ...

    @property
    def Cyan(self) -> float:
        """
        Read-write. The cyan color value (as percent) (0.0 - 100.0).
        """
        ...

    @property
    def Magenta(self) -> float:
        """
        Read-write. The magenta color value (as percent) (0.0 - 100.0).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced CMYKColor object.
        """
        ...

    @property
    def Yellow(self) -> float:
        """
        Read-write. The yellow color value (as percent) (0.0 - 100.0).
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document
    from .application import Application
    from .layercomp import LayerComp

class LayerComps():
    """
    The collection of LayerComp objects in the document. Note: See “LayerComp ” on page 96 for information on LayerComp objects.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the LayerComps collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The LayerComps object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced LayerComps object.
        """
        ...

    def Add(self, Name:str, Comment:str, Appearance:bool, Position:bool, Visibility:bool) -> LayerComp:
        """
        Adds a layer comp.
        """
        ...

    def Index(self, ItemPtr:LayerComp) -> int:
        """
        Gets the index of the LayerComp into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> LayerComp:
        """
        Gets an element from the LayerComps collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all LayerComp objects from the LayerComps collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .notifier import Notifier

class Notifiers():
    """
    The collection of Notifier objects in the document; the Notifiers property of the Application object. Note: See ‘Notifier ’ on page 106 for information on Notifier objects. See Notifiers (in the Properties table of the Application object).
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the Notifiers collection.
        """
        ...

    @property
    def EventClass(self) -> str:
        """
        Read-only. The class ID of the event.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The Notifiers object’s container
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Notifiers object.
        """
        ...

    def Add(self, Event:str, EventFile:str, EventClass:str) -> Notifier:
        """
        Creates a Notifier object. Note: EventClass defines the class ID of the event: four characters or a unique string . For a list of four-character codes, see Appendix A: Event ID Codes. Tip:Remember to omit the single quotes when including a four-character ID in your code. Note: EventFile defines the script file that executes when the event occurs. Note:An eventClass value corresponds to the class of object the event is applied to: four characters or a unique string. When an event applies to multiple types of objects, you use the EventClass parameter to distinguish which object this Notifier applies to. For example, the Make event (“Mk “)applies to documents (“Dcmn”), channels (“Chnl”) and other objects.
        """
        ...

    def Index(self, ItemPtr:Notifier) -> int:
        """
        Gets the index of the Notifier into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> Notifier:
        """
        Gets an element from the Notifiers collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all Notifier objects from the Notifiers collection. Note:You can remove a notifier object from the Script Events Manager drop-down list by deleting the file named Script Events Manager.xml from in the Photoshop preferences folder. See Adobe Photoshop help for more information.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psorientation import PsOrientation
    from .application import Application
    from .psphotocdsize import PsPhotoCDSize
    from .psphotocdcolorspace import PsPhotoCDColorSpace

class PhotoCDOpenOptions():
    """
    DEPRECATED in Adobe Photoshop. Kodak PhotoCD is now found in the Goodies folder on the Adobe Photoshop Install DVD.Options to be specified when opening a Kodak Photo CD (PCD) files, including high-resolution files from Pro Photo CD discs.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ColorProfileName(self) -> str:
        """
        Read-write. The profile to use when reading the image.
        """
        ...

    @property
    def ColorSpace(self) -> PsPhotoCDColorSpace:
        """
        Read-write. The colorspace for the image.
        """
        ...

    @property
    def Orientation(self) -> PsOrientation:
        """
        Read-write. The image orientation.
        """
        ...

    @property
    def PixelSize(self) -> PsPhotoCDSize:
        """
        Read-write. The image dimensions.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The image resolution (in pixels per inch).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PhotoCDOpenOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .subpathitem import SubPathItem
    from .application import Application
    from .pathpoint import PathPoint

class PathPoints():
    """
    A collection of PathPoint objects that comprises the PathPoints property of the SubPathItem object.Note: See ‘SubPathItem ’ on page 144 for more information.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the PathPoints collection.
        """
        ...

    @property
    def Parent(self) -> SubPathItem:
        """
        Read-only. The PathPoints object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PathPoints object.
        """
        ...

    def Index(self, ItemPtr:PathPoint) -> int:
        """
        Gets the index of the PathPoint into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> PathPoint:
        """
        Gets an element from the PathPoints collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document
    from .psdcstype import PsDCSType
    from .pssaveencoding import PsSaveEncoding
    from .application import Application
    from .countitem import CountItem
    from .pspreviewtype import PsPreviewType

class CountItems():
    """
    The collection of CountItems objects in the document. See CountItem.Note:CountItems is available in the Extended Version only.
    """
    @property
    def Length(self) -> int:
        """
        Read-only. The number of elements in the CountItems collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The CountItems object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced CountItems object.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def DCS(self) -> PsDCSType:
        """
        Read-write. Default: 3.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document
        """
        ...

    @property
    def Encoding(self) -> PsSaveEncoding:
        """
        Read-write. The type of encoding to use for document. Default: 1.
        """
        ...

    @property
    def HalftoneScreen(self) -> bool:
        """
        Read-write. Indicates whether to include halftone screen. Default: false.
        """
        ...

    @property
    def Interpolation(self) -> bool:
        """
        Read-write. Indicates whether to use image interpolation. Default: false)
        """
        ...

    @property
    def Preview(self) -> PsPreviewType:
        """
        Read-write. The type of preview. Default: 3.
        """
        ...

    @property
    def TransferFunction(self) -> bool:
        """
        Read-write. Indicates whether to include the Transfer functions to compensate for dot gain between the image and film. Default: false.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced DCS1_SaveOptions object.
        """
        ...

    @property
    def VectorData(self) -> bool:
        """
        Read-write. Indicates whether to include vector data. Note:Valid only if the document includes vector data (un-rasterized text).
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def DCS(self) -> PsDCSType:
        """
        Read-write. The type of composite file to create. Default: 1.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document.
        """
        ...

    @property
    def Encoding(self) -> PsSaveEncoding:
        """
        Read-write. The type of encoding to use. Default: 1.
        """
        ...

    @property
    def HalftoneScreen(self) -> bool:
        """
        Read-write. Indicates whether to include the halftone screen. Default: false.
        """
        ...

    @property
    def Interpolation(self) -> bool:
        """
        Read-write. Indicates whether to use image interpolation. Default: false.
        """
        ...

    @property
    def MultiFileDCS(self) -> bool:
        """
        Read-write. Indicates whether to save color channels as multiple files or a single file. Default: false.
        """
        ...

    @property
    def Preview(self) -> PsPreviewType:
        """
        Read-write. The preview type. Default: 3.
        """
        ...

    @property
    def SpotColors(self) -> bool:
        """
        Read-write. Indicates whether to save spot colors.
        """
        ...

    @property
    def TransferFunction(self) -> bool:
        """
        Read-write. Indicates whether to include the Transfer functions to compensate for dot gain between the image and film. Default: false.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced DCS2_SaveOptions object.
        """
        ...

    @property
    def VectorData(self) -> bool:
        """
        Read-write. Indicates whether to include vector data. Note:Valid only if the document includes vector data (un-rasterized text).
        """
        ...

    def Add(self, position:List[float]) -> CountItem:
        """
        Creates a new CountItem object. Parameter position (x,y) represents the horizontal and vertical positions, respectively, of the new CountItem object.
        """
        ...

    def Index(self, ItemPtr:CountItem) -> int:
        """
        Gets the index of the CountItem into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> Document:
        """
        Gets an element from the CountItem collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all CountItem objects from the CountItem collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psblendmode import PsBlendMode
    from .document import Document
    from .layerset import LayerSet
    from .application import Application
    from .layers import Layers
    from .artlayer import ArtLayer
    from .layersets import LayerSets
    from .channel import Channel
    from .psanchorposition import PsAnchorPosition
    from .pselementplacement import PsElementPlacement
    from .artlayers import ArtLayers

class LayerSet():
    """
    A group of layer object s, which can include ArtLayer objects and other (nested) LayerSet objects. A single command or set of commands manipulates all layers in a LayerSet object. 
    """
    @property
    def AllLocked(self) -> bool:
        """
        Read-write. Indicates whether the contents in the layers contained in the LayerSet object are editable.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ArtLayers(self) -> ArtLayers:
        """
        Read-only. The ArtLayers in this LayerSet.
        """
        ...

    @property
    def BlendMode(self) -> PsBlendMode:
        """
        Read-write. The blend mode to use for the layer set.
        """
        ...

    @property
    def Bounds(self) -> List[float]:
        """
        Read-only. The bounding rectangle of the layer set.
        """
        ...

    @property
    def EnabledChannels(self) -> List[Channel]:
        """
        Read-write. The channels enabled for the layer set; must be a list of component channels. Note:See Kind in the Properties table for the Channel Object (‘Channel’ on page 43).
        """
        ...

    @property
    def Layers(self) -> Layers:
        """
        Read-only. The layers in this LayerSet object.
        """
        ...

    @property
    def LayerSets(self) -> LayerSets:
        """
        Read-only. The top level LayerSets in this document.
        """
        ...

    @property
    def LinkedLayers(self) -> List[ArtLayer]:
        """
        Read-only. The layers linked to this LayerSet object.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The name of the LayerSet object.
        """
        ...

    @property
    def Opacity(self) -> float:
        """
        Read-write. The master opacity of the LayerSet Object (0.0 - 100.0).
        """
        ...

    @property
    def Parent(self) -> Document|LayerSet:
        """
        Read-only. The LayerSet object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced LayerSet object.
        """
        ...

    @property
    def Visible(self) -> bool:
        """
        Read-write. Indicates whether the LayerSet object is visible.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes the LayerSet object.
        """
        ...

    def Duplicate(self, RelativeObject:ArtLayer|LayerSet, InsertionLocation:PsElementPlacement):
        """
        Creates a duplicate of the LayerSet object.
        """
        ...

    def Link(self, With:ArtLayer|LayerSet) -> None:
        """
        Links the layer set with another layer.
        """
        ...

    def Merge(self) -> ArtLayer:
        """
        Merges the layerset; returns a reference to the art layer created by this method.
        """
        ...

    def Move(self, RelativeObject:Application, InsertionLocation:PsElementPlacement) -> None:
        """
        Moves the LayerSet object.
        """
        ...

    def Resize(self, Horizontal:float, Vertical:float, Anchor:PsAnchorPosition) -> None:
        """
        Resizes all layers in the layer set to the specified dimensions (as a percentage of its current size) and places the layer set in the specified position.
        """
        ...

    def Rotate(self, Angle:float, Anchor:PsAnchorPosition) -> None:
        """
        Rotates all layers in the layer set around the specified anchor point.
        """
        ...

    def Translate(self, DeltaX:float, DeltaY:float) -> None:
        """
        Moves the position relative to its current position.
        """
        ...

    def Unlink(self) -> None:
        """
        Unlinks the layer set.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class HSBColor():
    """
    Options that can be specified for a co lor object using the HSB color model. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Brightness(self) -> float:
        """
        Read-write. The brightness value (0.0 - 100.0).
        """
        ...

    @property
    def Hue(self) -> float:
        """
        Read-write. The hue value (0.0 - 100.0).
        """
        ...

    @property
    def Saturation(self) -> float:
        """
        Read-write. The saturation value (0.0 - 100.0).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced HSBColor object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psformatoptionstype import PsFormatOptionsType
    from .application import Application
    from .psmattetype import PsMatteType

class JPEGSaveOptions():
    """
    Options that can be specified when saving a document in JPEG format. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document.
        """
        ...

    @property
    def FormatOptions(self) -> PsFormatOptionsType:
        """
        Read-write.The download format to use. Default: 1 (psStandardBaseline).
        """
        ...

    @property
    def Matte(self) -> PsMatteType:
        """
        Read-write. The color to use to fill antialiased edges adjacent to transparent areas of the image. Default: 4 (psWhiteMatte). Note:When Transparency = false, the matte color is applied to transparent areas. See Transparency.
        """
        ...

    @property
    def Quality(self) -> int:
        """
        Read-write. The image quality setting to use (affects file size and compression) (0 - 12; default: 3).
        """
        ...

    @property
    def Scans(self) -> int:
        """
        Read-write. The number of scans to make to incrementally display the image on the page (3 - 5; default: 3). Note:Valid only for when FormatOptions = 3 (psProgressive).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced JPEGSaveOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .pstargabitsperpixels import PsTargaBitsPerPixels

class TargaSaveOptions():
    """
    Options that can be set when saving a document in TGA (Targa) format. 
    """
    @property
    def AlphaChannels(self) -> bool:
        """
        Read-write. Indicates whether to save the alpha channels.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Resolution(self) -> PsTargaBitsPerPixels:
        """
        Read-write. The number of bits per pixel. Default: 24.
        """
        ...

    @property
    def RLECompression(self) -> bool:
        """
        Read-write. Indicates whether RLE compression should be used. Default: true.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced TargaSaveOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pscase import PsCase
    from .psantialias import PsAntiAlias
    from .pstextcomposer import PsTextComposer
    from .psdirection import PsDirection
    from .pswarpstyle import PsWarpStyle
    from .application import Application
    from .psunderlinetype import PsUnderlineType
    from .psautokerntype import PsAutoKernType
    from .artlayer import ArtLayer
    from .psstrikethrutype import PsStrikeThruType
    from .pstexttype import PsTextType
    from .pslanguage import PsLanguage
    from .solidcolor import SolidColor
    from .psjustification import PsJustification

class TextItem():
    """
    The text in an ArtLayer object whose Kind property’s value is 2.Note: See ArtLayer , specifically the Kind property, for more information.
    """
    @property
    def AlternateLigatures(self) -> bool:
        """
        Read-write. Indicates whether to use alternate ligatures. Note:Alternate ligatures are the same as Discretionary Ligatures. Please refer to Adobe Photoshop Help for more information.
        """
        ...

    @property
    def AntiAliasMethod(self) -> PsAntiAlias:
        """
        Read-write. The method of anti aliasing to use.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def AutoKerning(self) -> PsAutoKernType:
        """
        Read-write. The auto kerning option to use.
        """
        ...

    @property
    def AutoLeadingAmount(self) -> float:
        """
        Read-write. The percentage to use for auto. Default) leading (0.01 - 5000.00 in points). Note:Valid only when UseAutoLeading = true. See UseAutoLeading.
        """
        ...

    @property
    def BaselineShift(self) -> float:
        """
        Read-write. The unit value to use in the baseline offset of text.
        """
        ...

    @property
    def Capitalization(self) -> PsCase:
        """
        Read-write. The text case.
        """
        ...

    @property
    def Color(self) -> SolidColor:
        """
        Read-write. The text color.
        """
        ...

    @property
    def Contents(self) -> str:
        """
        Read-write. The actual text in the layer.
        """
        ...

    @property
    def DesiredGlyphScaling(self) -> float:
        """
        Read-write. The desired amount (percentage) to scale the horizontal size of the text letters (50 - 200; at 100, the width of characters is not scaled). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MinimumGlyphScaling and MaximumGlyphScaling.
        """
        ...

    @property
    def DesiredLetterScaling(self) -> float:
        """
        Read-write. The amount of space between letters (100 - 500; at 0, no space is added between letters). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MinimumLetterScaling and MaximumLetterScaling.
        """
        ...

    @property
    def DesiredWordScaling(self) -> float:
        """
        Read-write. The amount (percentage) of space between words (0 -1000; at 100, no additional space is added between words). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MinimumWordScaling and MaximumWordScaling.
        """
        ...

    @property
    def Direction(self) -> PsDirection:
        """
        Read-write. The text orientation.
        """
        ...

    @property
    def FauxBold(self) -> bool:
        """
        Read-write. Indicates whether to use faux bold. Default: false. Note:Using FauxBold.true is equivalent to selecting text and clicking the Faux Bold button in the Character palette.
        """
        ...

    @property
    def FauxItalic(self) -> bool:
        """
        Read-write. Indicates whether to use faux italic. Default: false. Note:Using FauxItalic.true is equivalent to selecting text and clicking the Faux Italic button in the Character palette.
        """
        ...

    @property
    def FirstLineIndent(self) -> float:
        """
        Read-write. The amount (unit value) to indent the first line of paragraphs (-1296 - 1296).
        """
        ...

    @property
    def Font(self) -> str:
        """
        Read-write. The text face of the character.
        """
        ...

    @property
    def HangingPunctuation(self) -> bool:
        """
        Read-write. Indicates whether to use roman Hanging Punctuation.
        """
        ...

    @property
    def Height(self) -> float:
        """
        Read-write. The height of the bounding box (unit value) for paragraph text. Note:Valid only when Kind = 2 (psParagraphText). See Kind.
        """
        ...

    @property
    def HorizontalScale(self) -> int:
        """
        Read-write. Character scaling (horizontal) in proportion to vertical scale (0 - 1000 in percent). See VerticalScale.
        """
        ...

    @property
    def HyphenateAfterFirst(self) -> int:
        """
        Read-write. The number of letters after which hyphenation in word wrap is allowed (1 - 15).
        """
        ...

    @property
    def HyphenateBeforeLast(self) -> int:
        """
        Read-write. The number of letters before which hyphenation in word wrap is allowed (1 - 15).
        """
        ...

    @property
    def HyphenateCapitalWords(self) -> bool:
        """
        Read-write. Indicates whether to allow hyphenation in word wrap of capitalized words.
        """
        ...

    @property
    def HyphenateWordsLongerThan(self) -> int:
        """
        Read-write. The minimum number of letters a word must have in order for hyphenation in word wrap to be allowed (2 - 25).
        """
        ...

    @property
    def Hyphenation(self) -> bool:
        """
        Read-write. Indicates whether to use hyphenation in word wrap.
        """
        ...

    @property
    def HyphenationZone(self) -> float:
        """
        Read-write. The distance at the end of a line that will cause a word to break in unjustified type (0 - 720 pica).
        """
        ...

    @property
    def HyphenLimit(self) -> int:
        """
        Read-write. The maximum number of consecutive lines that can end with a hyphenated word.
        """
        ...

    @property
    def Justification(self) -> PsJustification:
        """
        Read-write. The paragraph justification.
        """
        ...

    @property
    def Kind(self) -> PsTextType:
        """
        Read-write. The text-wrap type.
        """
        ...

    @property
    def Language(self) -> PsLanguage:
        """
        Read-write. The language to use.
        """
        ...

    @property
    def Leading(self) -> float:
        """
        Read-write. The leading amount (unit value).
        """
        ...

    @property
    def LeftIndent(self) -> float:
        """
        Read-write. The amount (unit value) of space to indent text from the left (-1296 - 1296).
        """
        ...

    @property
    def Ligatures(self) -> bool:
        """
        Read-write. Indicates whether to use ligatures.
        """
        ...

    @property
    def MaximumGlyphScaling(self) -> float:
        """
        Read-write. The maximum amount (percentage) to scale the horizontal size of the text letters (50 - 200; at 100, the width of characters is not scaled). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MinimumGlyphScaling and DesiredGlyphScaling.
        """
        ...

    @property
    def MaximumLetterScaling(self) -> float:
        """
        Read-write. The maximum amount of space to allow between letters (100 - 500; at 0, no space is added between letters). Note:Valid only when Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MaximumLetterScaling and DesiredLetterScaling.
        """
        ...

    @property
    def MaximumWordScaling(self) -> float:
        """
        Read-write. The maximum amount (percentage) of space to allow between words (0 -1000; at 100, no additional space is added between words). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MaximumWordScaling and DesiredWordScaling.
        """
        ...

    @property
    def MinimumGlyphScaling(self) -> float:
        """
        Read-write. The minimum amount (percentage) to scale the horizontal size of the text letters (50 - 200; at 100, the width of characters is not scaled). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MaximumGlyphScaling and DesiredGlyphScaling.
        """
        ...

    @property
    def MinimumLetterScaling(self) -> float:
        """
        Read-write. The minimum amount (percentage) of space between letters (100 - 500; at 0, no space is removed between letters). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MaximumLetterScaling and DesiredLetterScaling.
        """
        ...

    @property
    def MinimumWordScaling(self) -> float:
        """
        Read-write. The minimum amount (percentage) of space between words (0 -1000; at 100, no space is removed between words). Note:Valid only when Justification = 4 (psLeftJustified); 5 (psCenterJustified); 6 (psRightJustified); or 7 (psFullyJustified). See Justification. The following values are also required: MaximumWordScaling and DesiredWordScaling.
        """
        ...

    @property
    def NoBreak(self) -> bool:
        """
        Read-write. Indicates whether to allow words to break at the end of a line. Tip:When enacted on large amounts of consecutive characters, noBreak = true can prevent word wrap and thus may prevent some text from appearing on the screen.
        """
        ...

    @property
    def OldStyle(self) -> bool:
        """
        Read-write. Indicates whether to use old style type.
        """
        ...

    @property
    def Parent(self) -> ArtLayer:
        """
        Read-write. The TextItem object's container.
        """
        ...

    @property
    def Position(self) -> List[float]:
        """
        Read-write. The position of origin for the text. The array must contain two values (unit value). Tip:Setting the Position property is basically equivalent to clicking the text tool at a point in the document to create the point of origin for text.
        """
        ...

    @property
    def RightIndent(self) -> float:
        """
        Read-write. The amount of space (unit value) to indent text from the right (-1296 - 1296).
        """
        ...

    @property
    def Size(self) -> float:
        """
        Read-write. The font size (unit value).
        """
        ...

    @property
    def SpaceAfter(self) -> float:
        """
        Read-write. The amount of space (unit value) to use after each paragraph (-1296 - 1296).
        """
        ...

    @property
    def SpaceBefore(self) -> float:
        """
        Read-write. The amount of space (unit value) to use before each paragraph (-1296 - 1296).
        """
        ...

    @property
    def StrikeThru(self) -> PsStrikeThruType:
        """
        Read-write. The text strike through option to use.
        """
        ...

    @property
    def TextComposer(self) -> PsTextComposer:
        """
        Read-write. The composition method to use to evaluate line breaks and optimize the specified hyphenation and Justification options. Note:Valid only when Kind = 2 (psParagraphText). See Kind.
        """
        ...

    @property
    def Tracking(self) -> float:
        """
        Read-write. The amount of uniform spacing between multiple characters (-1000 - 10000). Note:Tracking units are 1/1000 of an em space. The width of an em space is relative to the current type size. In a 1-point font, 1 em equals 1 point; in a 10-point font, 1 em equals 10 points. So, for example, 100 units in a 10-point font are equivalent to 1 point.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced TextItem object.
        """
        ...

    @property
    def Underline(self) -> PsUnderlineType:
        """
        Read-write. The text underlining options.
        """
        ...

    @property
    def UseAutoLeading(self) -> bool:
        """
        Read-write. Indicates whether to use a font's built-in leading information.
        """
        ...

    @property
    def VerticalScale(self) -> int:
        """
        Read-write. Character scaling (vertical) in proportion to horizontal scale (0 - 1000 in percent). See HorizontalScale.
        """
        ...

    @property
    def WarpBend(self) -> float:
        """
        Read-write. The warp bend percentage (-100 - 100).
        """
        ...

    @property
    def WarpDirection(self) -> PsDirection:
        """
        Read-write. The warp direction.
        """
        ...

    @property
    def WarpHorizontalDistortion(self) -> float:
        """
        Read-write. The horizontal distortion (as percentage) of the warp (-100 - 100).
        """
        ...

    @property
    def WarpStyle(self) -> PsWarpStyle:
        """
        Read-write. The style of warp to use.
        """
        ...

    @property
    def WarpVerticalDistortion(self) -> float:
        """
        Read-write. The vertical distortion (as percentage) of the warp (-100 - 100).
        """
        ...

    @property
    def Width(self) -> float:
        """
        Read-write. The width of the bounding box (unit value) for paragraph text. Note:Valid only when Kind = 2 (psParagraphText). See Kind.
        """
        ...

    def ConvertToShape(self) -> None:
        """
        Converts the text item and its containing layer to a fill layer with the text changed to a clipping path.
        """
        ...

    def CreatePath(self) -> None:
        """
        Creates a clipping path from the outlines of the actual text items (such as letters or words).
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .document import Document

class XMPMetadata():
    """
    Camera raw image file settings stored in an XMP file in the same folder as the raw file with the same base name and an XMP extension.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def RawData(self) -> str:
        """
        Read-write. The raw XML form of file information.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced XMPMetadata object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .subpathitem import SubPathItem
    from .application import Application
    from .pspointkind import PsPointKind

class PathPoint():
    """
    Information about an array of PathPointInfo objects.Note: You do not use the PathPoint object to create points that make up a path. Rather, you use the PathPoint object to retrieve information about the points that describe path segments. To create path points, use the PathPointInfo objects. See ‘PathPointInfo ’ on page 115.
    """
    @property
    def Anchor(self) -> List[float]:
        """
        Read-only. The point on the curve (LeftDirection/RightDirection are points representing the control handle end points).
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Kind(self) -> PsPointKind:
        """
        Read-only. The PathPoint object’s type.
        """
        ...

    @property
    def LeftDirection(self) -> List[float]:
        """
        Read-only. The x and y coordinates that define the left handle.
        """
        ...

    @property
    def Parent(self) -> SubPathItem:
        """
        Read-only. The PathPoint object's container.
        """
        ...

    @property
    def RightDirection(self) -> List[float]:
        """
        Read-only. The x and y coordinates that define the right handle.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PathPoint object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psmeasurementrange import PsMeasurementRange

class MeasurementLog():
    """
    The measurement log for the application. See MeasurementLog (in the Properties table for the Application object.)Note: The MeasurementLog feature is available in the Extended Version only.Because the MeasurementLog class is a property of the Application object, you use the property name, measurementLog , rather than the class name, MeasurementLog , in your code.
    """
    def ExportMeasurements(self, File, Range) -> None:
        """
        Export some measurement(s).
        """
        ...

    def DeleteMeasurements(self, Range:PsMeasurementRange) -> None:
        """
        Delete a measurement.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .pspictcompression import PsPICTCompression
    from .pspictbitsperpixels import PsPICTBitsPerPixels

class PICTFileSaveOptions():
    """
    Options that can be specified when saving a document in PICT format. 
    """
    @property
    def AlphaChannels(self) -> bool:
        """
        Read-write. Indicates whether to save the alpha channels.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Compression(self) -> PsPICTCompression:
        """
        Read-write. Default: 1)
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document.
        """
        ...

    @property
    def Resolution(self) -> PsPICTBitsPerPixels:
        """
        Read-write. The number of bits per pixel.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PICTFileSaveOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .document import Document
    from .historystate import HistoryState

class HistoryStates():
    """
    The collection of HistoryState objects in the document. Note: See ‘HistoryState ’ on page 89 for more information on HistoryState objects.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the HistoryStates collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The HistoryStates object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced HistoryStates object.
        """
        ...

    def Index(self, ItemPtr:HistoryState) -> int:
        """
        Gets the index of the HistoryState into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> HistoryState:
        """
        Gets an element from the HistoryStates collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psgallerythumbsizetype import PsGalleryThumbSizeType
    from .psgalleryfonttype import PsGalleryFontType

class GalleryThumbnailOptions():
    """
    Options that define the thumbnailOptions property of the GalleryOptions object. See ‘GalleryOptions ’ on page 82.Tip: You can preserve default values for many GalleryThumbnailOptions properties by setting the GalleryOptions property PreserveAllMetadata to true or by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Border(self) -> int:
        """
        Read-write. The amount of border pixels you want around your thumbnail images (0 - 99; default: 0).
        """
        ...

    @property
    def Caption(self) -> bool:
        """
        Read-write. Indicates whether there is a caption. Default: false.
        """
        ...

    @property
    def ColumnCount(self) -> int:
        """
        Read-write. The number of columns on the page. Default: 5.
        """
        ...

    @property
    def Dimension(self) -> int:
        """
        Read-write. The Web photo gallery thumbnail dimension in pixels. Default: 75.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The Web photo gallery font. Default: 1.
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The font size for thumbnail images text (1 - 7; default: 3).
        """
        ...

    @property
    def IncludeCopyright(self) -> bool:
        """
        Read-write. Indication of whether to include copyright information for thumbnails. Default: false.
        """
        ...

    @property
    def IncludeCredits(self) -> bool:
        """
        Read-write. Indication of whether to include credits for thumbnails. Default: false.
        """
        ...

    @property
    def IncludeFilename(self) -> bool:
        """
        Read-write. Indication of whether to include file names for thumbnails. Default: false.
        """
        ...

    @property
    def IncludeTitle(self) -> bool:
        """
        Read-write. Indication of whether to include titles for thumbnails. Default: false.
        """
        ...

    @property
    def RowCount(self) -> int:
        """
        Read-write. The number of rows on the page. Default: 3.
        """
        ...

    @property
    def Size(self) -> PsGalleryThumbSizeType:
        """
        Read-write. The thumbnail image size. Default: 2.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GalleryThumbnailOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psfilenamingtype import PsFileNamingType
    from .psbatchdestinationtype import PsBatchDestinationType

class BatchOptions():
    """
    Options to specify when running a Batch command. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Destination(self) -> PsBatchDestinationType:
        """
        Read-write. The type of destination for the processed files. Default: 1(psNoDestination).
        """
        ...

    @property
    def DestinationFolder(self) -> str:
        """
        Read-write. The folder location for the processed files. Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...

    @property
    def ErrorFile(self) -> str:
        """
        Read-write. The file in which to log errors encountered. Note:To display errors on the screen (and stop batch processing when errors occur) leave blank.
        """
        ...

    @property
    def FileNaming(self) -> List[PsFileNamingType]:
        """
        Read-write. A list of file naming options (maximum: 6). Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...

    @property
    def MacintoshCompatible(self) -> bool:
        """
        Read-write. Indicates whether to make the final file names Macintosh compatible. Default: true. Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...

    @property
    def OverrideOpen(self) -> bool:
        """
        Read-write. Indicates whether to override action open commands. Default: false.
        """
        ...

    @property
    def OverrideSave(self) -> bool:
        """
        Read-write. Indicates whether to override save as action steps with the specified destination. Default: false. Note:Valid only when Destination = 3 (psFolder). or Destination = 2 (psSaveAndClose). See Destination.
        """
        ...

    @property
    def StartingSerial(self) -> int:
        """
        Read-write. The starting serial number to use in naming files. Default: 1. Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...

    @property
    def SuppressOpen(self) -> bool:
        """
        Read-write. Indicates whether to suppress the file open options dialogs. Default: false.
        """
        ...

    @property
    def SuppressProfile(self) -> bool:
        """
        Read-write. Indicates whether to suppress the color profile warnings. Default: false.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced BatchOptions object.
        """
        ...

    @property
    def UnixCompatible(self) -> bool:
        """
        Read-write. Indicates whether to make the final file name Unix® compatible. Default: true. Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...

    @property
    def WindowsCompatible(self) -> bool:
        """
        Read-write. Indicates whether to make the final file names Windows compatible. Default: true. Note:Valid only when Destination = 3 (psFolder). See Destination.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .number import number
    from .document import Document
    from .colorsampler import ColorSampler

class ColorSamplers():
    """
    The collection of ColorSampler objects in the document. See ColorSampler.
    """
    @property
    def Length(self) -> int:
        """
        Read-only. The number of elements in the ColorSamplers collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The ColorSamplers object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ColorSamplers object.
        """
        ...

    def Add(self, position:List[float]) -> ColorSampler:
        """
        Creates a new ColorSampler object. The position parameter (x,y) represents the horizontal and vertical locations, respectively, of the new color sampler.
        """
        ...

    def Index(self, ItemPtr:ColorSampler) -> int:
        """
        Gets the index of the ColorSampler into the collection.
        """
        ...

    def Item(self, ItemKey:number) -> ColorSampler:
        """
        Gets an element from the ColorSamplers collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all ColorSampler objects from the ColorSamplers collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .layerset import LayerSet
    from .application import Application
    from .document import Document
    from .artlayer import ArtLayer

class Layers():
    """
    The collection of layer objects, including ArtLayer and LayerSet objects, in the document. Note: See “ArtLayer ” on page 24 for information on ArtLayer objects. See “LayerSet ” on page 99 for information on LayerSet objects.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the Layers collection.
        """
        ...

    @property
    def Parent(self) -> Document|LayerSet:
        """
        Read-only. The Layers object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Layers object.
        """
        ...

    def Index(self, ItemPtr:ArtLayer|LayerSet) -> int:
        """
        Gets the index of the ArtLayer or LayerSet into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> ArtLayer|LayerSet:
        """
        Gets an element from the collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all layers from the collection.
        """
        ...




_3DTransform = "TdT"
Average = "Avrg"
ApplyStyle = "ASty"
Assert = "Asrt"
AccentedEdges = "AccE"
Add = "Add"
AddNoise = "AdNs"
AddTo = "AddT"
Align = "Algn"
All = "All"
AngledStrokes = "AngS"
ApplyImage = "AppI"
BasRelief = "BsRl"
Batch = "Btch"
BatchFromDroplet = "BtcF"
Blur = "Blr"
BlurMore = "BlrM"
Border = "Brdr"
Brightness = "BrgC"
CanvasSize = "CnvS"
ChalkCharcoal = "ChlC"
ChannelMixer = "ChnM"
Charcoal = "Chrc"
Chrome = "Chrm"
Clear = "Cler"
Close = "Cls"
Clouds = "Clds"
ColorBalance = "ClrB"
ColorHalftone = "ClrH"
ColorRange = "ClrR"
ColoredPencil = "ClrP"
ContactSheet = "0B71D221-F8CE-11d2-B21B-0008C75B322 C"
ConteCrayon = "CntC"
Contract = "Cntc"
ConvertMode = "CnvM"
Copy = "copy"
CopyEffects = "CpFX"
CopyMerged = "CpyM"
CopyToLayer = "CpTL"
Craquelure = "Crql"
CreateDroplet = "CrtD"
Crop = "Crop"
Crosshatch = "Crsh"
Crystallize = "Crst"
Curves = "Crvs"
Custom = "Cstm"
Cut = "cut"
CutToLayer = "CtTL"
Cutout = "Ct"
DarkStrokes = "DrkS"
DeInterlace = "Dntr"
DefinePattern = "DfnP"
Defringe = "Dfrg"
Delete = "Dlt"
Desaturate = "Dstt"
Deselect = "Dslc"
Despeckle = "Dspc"
DifferenceClouds = "DfrC"
Diffuse = "Dfs"
DiffuseGlow = "DfsG"
DisableLayerFX = "dlfx"
Displace = "Dspl"
Distribute = "Dstr"
Draw = "Draw"
DryBrush = "DryB"
Duplicate = "Dplc"
DustAndScratches = "DstS"
Emboss = "Embs"
Equalize = "Eqlz"
Exchange = "Exch"
Expand = "Expn"
Export = "Expr"
Jumpto = "Jpto"
ExportTransparentImage = "02879e00-cb66-11d1-bc43-0060b0a13dc 4"
Extrude = "Extr"
Facet = "Fct"
Fade = "Fade"
Feather = "Fthr"
Fibers = "Fbrs"
Fill = "Fl"
FilmGrain = "FlmG"
Filter = "Fltr"
FindEdges = "FndE"
FitImage = "3caa3434-cb67-11d1-bc43-0060b0a13dc 4"
FlattenImage = "FltI"
Flip = "Flip"
Fragment = "Frgm"
Fresco = "Frsc"
GaussianBlur = "GsnB"
Get = "getd"
Glass = "Gls"
GlowingEdges = "GlwE"
Gradient = "Grdn"
GradientMap = "GrMp"
Grain = "Grn"
GraphicPen = "GraP"
Group = "GrpL"
Grow = "Grow"
HalftoneScreen = "HlfS"
Hide = "Hd"
HighPass = "HghP"
HSBHSL = "HsbP"
HueSaturation = "HStr"
ImageSize = "ImgS"
Import = "Impr"
InkOutlines = "InkO"
Intersect = "Intr"
IntersectWith = "IntW"
Inverse = "Invs"
Invert = "Invr"
LensFlare = "LnsF"
Levels = "Lvls"
LightingEffects = "LghE"
Link = "Lnk"
Make = "Mk"
Maximum = "Mxm"
Median = "Mdn"
MergeLayers = "Mrg2"
MergeLayersOld = "MrgL"
MergeSpotChannel = "MSpt"
MergeVisible = "MrgV"
Mezzotint = "Mztn"
Minimum = "Mnm"
ModeChange = "8cba8cd6-cb66-11d1-bc43-0060b0a13dc 4"
Mosaic = "Msc"
Mosaic_PLUGIN = "MscT"
MotionBlur = "MtnB"
Move = "move"
NTSCColors = "NTSC"
NeonGlow = "NGlw"
Next = "Nxt"
NotePaper = "NtPr"
Notify = "Ntfy"
Null = "typeNull"
OceanRipple = "OcnR"
Offset = "Ofst"
Open = "Opn"
Paint = "Pnt"
PaintDaubs = "PntD"
PaletteKnife = "PltK"
Paste = "past"
PasteEffects = "PaFX"
PasteInto = "PstI"
PasteOutside = "PstO"
Patchwork = "Ptch"
Photocopy = "Phtc"
PicturePackage = "4C1ABF40-DD82-11d2-B20F-0008C75B322 C"
Pinch = "Pnch"
Place = "Plc"
Plaster = "Plst"
PlasticWrap = "PlsW"
Play = "Ply"
Pointillize = "Pntl"
Polar = "Plr"
PosterEdges = "PstE"
Posterize = "Pstr"
Previous = "Prvs"
Print = "Prnt"
ProfileToProfile = "PrfT"
Purge = "Prge"
Quit = "quit"
RadialBlur = "RdlB"
Rasterize = "Rstr"
RasterizeTypeSheet = "RstT"
RemoveBlackMatte = "RmvB"
RemoveLayerMask = "RmvL"
RemoveWhiteMatte = "RmvW"
Rename = "Rnm"
ReplaceColor = "RplC"
Reset = "Rset"
ResizeImage = "1333cf0c-cb67-11d1-bc43-0060b0a13dc 4"
Reticulation = "Rtcl"
Revert = "Rvrt"
Ripple = "Rple"
Rotate = "Rtte"
RoughPastels = "RghP"
Save = "save"
Select = "slct"
SelectiveColor = "SlcC"
Set = "setd"
SharpenEdges = "ShrE"
Sharpen = "Shrp"
SharpenMore = "ShrM"
Shear = "Shr"
Show = "Shw"
Similar = "Smlr"
SmartBlur = "SmrB"
Smooth = "Smth"
SmudgeStick = "SmdS"
Solarize = "Slrz"
Spatter = "Spt"
Spherize = "Sphr"
SplitChannels = "SplC"
Sponge = "Spng"
SprayedStrokes = "SprS"
StainedGlass = "StnG"
Stamp = "Stmp"
Stop = "Stop"
Stroke = "Strk"
Subtract = "Sbtr"
SubtractFrom = "SbtF"
Sumie = "Smie"
TakeMergedSnapshot = "TkMr"
TakeSnapshot = "TkSn"
TextureFill = "TxtF"
Texturizer = "Txtz"
Threshold = "Thrs"
Tiles = "Tls"
TornEdges = "TrnE"
TraceContour = "TrcC"
Transform = "Trnf"
Trap = "Trap"
Twirl = "Twrl"
Underpainting = "Undr"
Undo = "undo"
Ungroup = "Ungr"
Unlink = "Unlk"
UnsharpMask = "UnsM"
Variations = "Vrtn"
Wait = "Wait"
WaterPaper = "WtrP"
Watercolor = "Wtrc"
Wave = "Wave"
Wind = "Wnd"
ZigZag = "ZgZg"
BackLight = "BacL"
FillFlash = "FilE"
ColorCast = "ColE"




from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .document import Document

class HistoryState():
    """
    A version of the document stored automatically (and added to the HistoryStates collection), which preserves the document’s state, each time the document is saved. Note: See “HistoryStates ” on page 90‘ for information about the HistoryStates collection. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-only. The HistoryState object's name.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The HistoryState object's container.
        """
        ...

    @property
    def Snapshot(self) -> bool:
        """
        Read-only. Indicates whether the history state is a snapshot.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced HistoryState object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psmagnificationtype import PsMagnificationType
    from .application import Application
    from .pdfsaveoptions import PDFSaveOptions
    from .pstransitiontype import PsTransitionType

class PresentationOptions():
    """
    Options that can be specified for PDF presentations. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def AutoAdvance(self) -> bool:
        """
        Read-write. Indicates whether to auto advance images when viewing the presentation. Default: true. Note:Valid only when Presentation = true. See Presentation.
        """
        ...

    @property
    def IncludeFilename(self) -> bool:
        """
        Read-write. Indicates whether to include the file name for the image (default: false).
        """
        ...

    @property
    def Interval(self) -> int:
        """
        Read-write. The time in seconds before the view is auto advanced (1 - 60; default: 5). Note:Valid only when AutoAdvance = true. See AutoAdvance.
        """
        ...

    @property
    def Loop(self) -> bool:
        """
        Read-write. Indicates whether to begin the presentation again after the last page. Default: false. Note:Valid only when AutoAdvance = true. See AutoAdvance.
        """
        ...

    @property
    def Magnification(self) -> PsMagnificationType:
        """
        Read-write. The magnification type to use when viewing the image.
        """
        ...

    @property
    def PDFFileOptions(self) -> PDFSaveOptions:
        """
        Read-write. Options to use when creating the PDF file.
        """
        ...

    @property
    def Presentation(self) -> bool:
        """
        Read-write. Indicates whether the output will be a presentation. Default: false); when false, the output is a Multi-Page document.
        """
        ...

    @property
    def Transition(self) -> PsTransitionType:
        """
        Read-write. The transition from one image to the next. Default: 9 (psNoTransition). Note:Valid only when AutoAdvance = true. See AutoAdvance.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PDFPresentationOptions object.
        """
        ...




class PsAdjustmentReference():
    """
    Method to use for interpreting selective color adjustment specifications: 1 = % of the existing color amount; 2 = % of the whole.
    """
    psRelative = 1
    psAbsolute = 2





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psbitmaphalftonetype import PsBitmapHalfToneType
    from .psbitmapconversiontype import PsBitmapConversionType

class BitmapConversionOptions():
    """
    Options to specify when converting an image to Bitmap mode.Note: Convert color images to grayscale before converting the image to bitmap mode. See ‘Desaturate ’ on page 31 (in the Properties table of the ArtLayer object). 
    """
    @property
    def Angle(self) -> float:
        """
        Read-write. The angle (in degrees) at which to orient individual dots (-180 - 180). See Shape. Note:Valid only when Method = 4. See Method.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Frequency(self) -> float:
        """
        Read-write. The number of printer dots (per inch) to use (1.0 - 999.99). Note:Valid only when Method = 4. See Method.
        """
        ...

    @property
    def Method(self) -> PsBitmapConversionType:
        """
        Read-write. The conversion method to use. Default: 3.
        """
        ...

    @property
    def PatternName(self) -> str:
        """
        Read-write. The name of the pattern to use. Note:Valid only when Method = 5. See Method.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The output resolution in pixels per inch. Default: 72.0.
        """
        ...

    @property
    def Shape(self) -> PsBitmapHalfToneType:
        """
        Read-write. The dot shape to use. Note:Valid only when Method = 1. See Method.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced BitmapConversionOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .colorsamplers import ColorSamplers
    from .pssaveoptions import PsSaveOptions
    from .countitems import CountItems
    from .xmpmetadata import XMPMetadata
    from .historystate import HistoryState
    from .application import Application
    from .layers import Layers
    from .channel import Channel
    from .documentinfo import DocumentInfo
    from .artlayers import ArtLayers
    from .historystates import HistoryStates
    from .channels import Channels
    from .psbitsperchanneltype import PsBitsPerChannelType
    from .psextensiontype import PsExtensionType
    from .pathitems import PathItems
    from .psanchorposition import PsAnchorPosition
    from .pscolorprofiletype import PsColorProfileType
    from .psdocumentmode import PsDocumentMode
    from .document import Document
    from .psdirection import PsDirection
    from .layerset import LayerSet
    from .artlayer import ArtLayer
    from .layercomps import LayerComps
    from .measurementscale import MeasurementScale
    from .selection import Selection
    from .arraydouble import arrayDouble
    from .layersets import LayerSets

class Document():
    """
    The active containment object for layers and all most objects in the script; the basic canvas for the file. Note: In Adobe Photoshop, a document can also be referred to as an image or a canvas. ?The term image refers to the entire document and its contents. You can trim or crop an image. You resize an image using the ResizeImage() method. ?The term canvas refers to the space in which the document sits on the screen. You can rotate or flip the canvas. You resize the canvas using the ResizeCanvas() method. 
    """
    @property
    def ActiveChannels(self) -> List[Channel]:
        """
        Read-write. The selected channels.
        """
        ...

    @property
    def ActiveHistoryBrushSource(self) -> HistoryState:
        """
        Read-write. The history state to use with the history brush.
        """
        ...

    @property
    def ActiveHistoryState(self) -> HistoryState:
        """
        Read-write. The selected HistoryState object.
        """
        ...

    @property
    def ActiveLayer(self) -> ArtLayer|LayerSet:
        """
        Read-write. The selected layer.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ArtLayers(self) -> ArtLayers:
        """
        Read-only. The ArtLayers collection.
        """
        ...

    @property
    def BackgroundLayer(self) -> ArtLayer:
        """
        Read-only. The background layer of the document.
        """
        ...

    @property
    def BitsPerChannel(self) -> PsBitsPerChannelType:
        """
        Read-write. The number of bits per channel.
        """
        ...

    @property
    def Channels(self) -> Channels:
        """
        Read-only. The Channels collection.
        """
        ...

    @property
    def ColorProfileName(self) -> str:
        """
        Read-write. The name of the color profile. Note:Valid only when ColorProfileType = 3 or ColorProfileType = 2. See ColorProfileType.
        """
        ...

    @property
    def ColorProfileType(self) -> PsColorProfileType:
        """
        Read-write. The type of color model that defines the document’s working space.
        """
        ...

    @property
    def ColorSamplers(self) -> ColorSamplers:
        """
        Read-only. The current color samplers associated with this document.
        """
        ...

    @property
    def ComponentChannels(self) -> List[Channel]:
        """
        Read-only. A list of the component color channels.
        """
        ...

    @property
    def CountItems(self) -> CountItems:
        """
        Read-only. The current count items. Note:For additional information about count items, see Adobe Photoshop help on the Coun Tool.
        """
        ...

    @property
    def FullName(self) -> str:
        """
        Read-only. The full path name of the document.
        """
        ...

    @property
    def Height(self) -> float:
        """
        Read-only. The height of the document (unit value).
        """
        ...

    @property
    def Histogram(self) -> List[int]:
        """
        Read-only. A histogram showing the number of pixels at each color intensity level for the composite channel. Note:Valid only when Mode = 2; Mode = 3; or Mode = 6. See Mode.
        """
        ...

    @property
    def HistoryStates(self) -> HistoryStates:
        """
        Read-only. The HistoryStates collection.
        """
        ...

    @property
    def Info(self) -> DocumentInfo:
        """
        Read-only. Metadata about the document.
        """
        ...

    @property
    def LayerComps(self) -> LayerComps:
        """
        Read-only. The LayerComps collection.
        """
        ...

    @property
    def Layers(self) -> Layers:
        """
        Read-only. The Layers collection.
        """
        ...

    @property
    def LayerSets(self) -> LayerSets:
        """
        Read-only. The LayerSets collection.
        """
        ...

    @property
    def Managed(self) -> bool:
        """
        Read-only. Indicates whether the document a is workgroup document.
        """
        ...

    @property
    def MeasurementScale(self) -> MeasurementScale:
        """
        Read-only. The measurement scale for the document. Note:This feature is available in the Extended Version only.
        """
        ...

    @property
    def Mode(self) -> PsDocumentMode:
        """
        Read-only. The color profile.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-only. The document's name.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The Document object's container.
        """
        ...

    @property
    def Path(self) -> str:
        """
        Read-only. The path to the document.
        """
        ...

    @property
    def PathItems(self) -> PathItems:
        """
        Read-only. The PathItems collection.
        """
        ...

    @property
    def PixelAspectRatio(self) -> float:
        """
        Read-write. The (custom) pixel aspect ratio to use (0.100 - 10.000).
        """
        ...

    @property
    def QuickMaskMode(self) -> bool:
        """
        Read-write. Indicates whether the document is in Quick Mask mode.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-only. The document’s resolution (in pixels per inch).
        """
        ...

    @property
    def Saved(self) -> bool:
        """
        Read-only. Indicates whether the document has been saved since the last change.
        """
        ...

    @property
    def Selection(self) -> Selection:
        """
        Read-only. The selected area of the document.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the Document object.
        """
        ...

    @property
    def Width(self) -> float:
        """
        Read-only. The width of the document (unit value).
        """
        ...

    @property
    def XMPMetadata(self) -> XMPMetadata:
        """
        Read-only. XMP data for the image. Camera Raw settings are contained here.
        """
        ...

    def AutoCount(self, channel, threshold) -> None:
        """
        Counts the number of objects in a document. Creates a CountItem object for each object counted. Note:The AutoCount feature is available in the Extended Version only. For additional information about how to set up objects to count, please see the Count Tool in the Adobe Photoshop Help
        """
        ...

    def ChangeMode(self, DestinationMode, Options) -> None:
        """
        Changes the color profile.
        """
        ...

    def Close(self, Saving:PsSaveOptions) -> None:
        """
        Closes the document. If any changes have been made, the script presents an alert with three options: save, do not save, prompt to save. The optional parameter specifies a selection in the alert box. Default: 3 (psPromptToSaveChange s).
        """
        ...

    def ConvertProfile(self, DestinationProfile, Intent, BlackPointCompensation, Dither) -> None:
        """
        Changes the color profile. Note:The DestinationProfi le parameter must be either a string that names the color mode or Working RGB, Working CMYK, Working Gray, Lab Color (meaning one of the working color spaces or Lab color)
        """
        ...

    def Crop(self, Bounds:arrayDouble, Angle:float, Width:float, Height:float) -> None:
        """
        Crops the document. The first parameter is an array of four coordinates that mark the portion remaining after cropping, in the following order: left, top, right, bottom.
        """
        ...

    def Duplicate(self, Name:str, MergeLayersOnly:bool):
        """
        Creates a duplicate of the Document object. The optional parameter Name provides the name for the duplicated document. The optional parameter MergeLayersOnly indicates whether to only duplicate merged layers.
        """
        ...

    def ExportDocument(self, ExportIn, ExportAs, Options) -> None:
        """
        Exports the document. Note:The ExportIn parameter represents the path to a file as String.
        """
        ...

    def Flatten(self) -> None:
        """
        Flattens all layers.
        """
        ...

    def FlipCanvas(self, Direction:PsDirection) -> None:
        """
        Flips the image within the canvas in the specified direction.
        """
        ...

    def ImportAnnotations(self, File:str) -> None:
        """
        Imports annotations into the document.
        """
        ...

    def MergeVisibleLayers(self) -> None:
        """
        Flattens all visible layers in the document.
        """
        ...

    def Paste(self, IntoSelection:bool) -> ArtLayer:
        """
        Pastes the contents of the clipboard into the document. If the optional argument is set to true and a selection is active, the contents are pasted into the selection.
        """
        ...

    def PrintOut(self, SourceSpace, PrintSpace, IntentBlackPointCompensation) -> None:
        """
        Prints the document. Note: PrintSpace specifies the color space for the printer. Valid values are nothing (that is, the same as the source); or Working RGB, Working CMYK, Working Gray, Lab Color (meaning one of the working color spaces or Lab color); or a string specifying a specific colorspace. Default: nothing).
        """
        ...

    def RasterizeAllLayers(self) -> None:
        """
        Rasterizes all layers.
        """
        ...

    def RecordMeasurements(self, Source, DataPoints) -> None:
        """
        Record measurements of document.
        """
        ...

    def ResizeCanvas(self, Width:float, Height:float, Anchor:PsAnchorPosition) -> None:
        """
        Changes the size of the canvas to display more or less of the image but does not change the image size. See ResizeImage.
        """
        ...

    def ResizeImage(self, Width, Height, Resolution, ResampleMethod, Amount) -> None:
        """
        Changes the size of the image.
        """
        ...

    def RevealAll(self) -> None:
        """
        Expands the document to show clipped sections.
        """
        ...

    def RotateCanvas(self, Angle:float) -> None:
        """
        Rotates the canvas (including the image) in clockwise direction.
        """
        ...

    def Save(self) -> None:
        """
        Saves the document.
        """
        ...

    def SaveAs(self, SaveIn:str, Options:Any, AsCopy:bool, ExtensionType:PsExtensionType) -> None:
        """
        Saves the document with specified save options. Note:The Options parameter’s value can be a value from the PsSaveDocumentType constant list, or any of the “SaveOptions” objects in the current chapter such as BMPSaveOptions, EPSSaveOptions, JPEGSaveOptions, and so on. Note:The SaveIn parameter represents the path to the file to save in as String.
        """
        ...

    def SplitChannels(self) -> List[Document]:
        """
        Splits the document channels into separate images.
        """
        ...

    def Trap(self, Width:int) -> None:
        """
        Applies trapping to a CMYK document. Note:Valid only when Mode = 3. See Mode.
        """
        ...

    def Trim(self, Type, Top, Left, Bottom, Right) -> None:
        """
        Trims the transparent area around the image on the specified sides of the canvas. Note:Default is true for all Boolean values.
        """
        ...




class PsAdjustmentReference():
    """
    Method to use for interpreting selective color adjustment specifications: 1 = % of the existing color amount; 2 = % of the whole.
    """
    psRelative = 1
    psAbsolute = 2

class PsAnchorPosition():
    """
    The point on the object that does not move when the object is rotated or resized.
    """
    psTopLeft = 1
    psTopCenter = 2
    psTopRight = 3
    psMiddleLeft = 4
    psMiddleCenter = 5
    psMiddleRight = 6
    psBottomLeft = 7
    psBottomCenter = 8
    psBottomRight = 9

class PsAntiAlias():
    """
    Method to use to smooth edges by softening the color transition between edge pixels and background pixels.
    """
    psNoAntialias = 1
    psSharp = 2
    psCrisp = 3
    psStrong = 4
    psSmooth = 5

class PsAutoKernType():
    """
    The type of kerning to use for characters.
    """
    psManual = 1
    psMetrics = 2
    psOptical = 3

class PsBatchDestinationType():
    """
    The destination, if any, for batch-processed files: 1: Leave all files open; 2: Save changes and close the files; 3: Save modified versions of the files to a new location (leaving the originals unchanged).
    """
    psNoDestination = 1
    psSaveAndClose = 2
    psFolder = 3

class PsBitmapConversionType():
    """
    Specifies the quality of an image you are converting to bitmap mode.
    """
    psHalfThreshold = 1
    psPatternDither = 2
    psDiffusionDither = 3
    psHalftoneScreen = 4
    psCustomPattern = 5

class PsBitmapHalfToneType():
    """
    Specifies the shape of the dots (ink deposits) in the halftone screen.
    """
    psHalftoneRound = 1
    psHalftoneDiamond = 2
    psHalftoneEllipse = 3
    psHalftoneLine = 4
    psHalftoneSquare = 5
    psHalftoneCross = 6

class PsBitsPerChannelType():
    """
    The number of bits per color channel.
    """
    psDocument1Bit = 1
    psDocument8Bits = 8
    psDocument16Bits = 16
    psDocument32Bits = 32

class PsBlendMode():
    """
    Controls how pixels in the image are blended.
    """
    psPassThrough = 1
    psNormalBlend = 2
    psDissolve = 3
    psDarken = 4
    psMultiply = 5
    psColorBurn = 6
    psLinearBurn = 7
    psLighten = 8
    psScreen = 9
    psColorDodge = 10
    psLinearDodge = 11
    psOverlay = 12
    psSoftLight = 13
    psHardLight = 14
    psVividLight = 15
    psLinearLight = 16
    psPinLight = 17
    psDifference = 18
    psExclusion = 19
    psHue = 20
    psSaturationBlend = 21
    psColorBlend = 22
    psLuminosity = 23
    psHardMix = 26
    psLighterColor = 27
    psDarkerColor = 28
    psSubtract = 29
    psDivide = 30

class PsBMPDepthType():
    """
    The number of bits per channel (also called pixel depth or color depth). The number selected indicates the exponent of 2. For example, a pixel with a bit-depth of 8 has 28, or 256, possible color values.
    """
    psBMP1Bit = 1
    psBMP4Bits = 4
    psBMP8Bits = 8
    psBMP16Bits = 16
    psBMP24Bits = 24
    psBMP32Bits = 32
    psBMP_X1R5G5B5 = 60
    psBMP_A1R5G5B5 = 61
    psBMP_R5G6B5 = 62
    psBMP_X4R4G4B4 = 63
    psBMP_A4R4G4B4 = 64
    psBMP_R8G8B8 = 65
    psBMP_X8R8G8B8 = 66
    psBMP_A8R8G8B8 = 67

class PsByteOrder():
    """
    The order in which bytes will be read.
    """
    psIBMByteOrder = 1
    psMacOSByteOrder = 2

class PsCameraRAWSettingsType():
    """
    The default CameraRAW settings to use: the camera settings, custom settings, or the settings of the selected image.
    """
    psCameraDefault = 0
    psSelectedImage = 1
    psCustomSettings = 2

class PsCameraRAWSize():
    """
    The camera RAW size type options: 0 = 1536 x 1024 1 = 2048 x 1365 2 = 3072 x 2048 3 = 4096 x 2731 4 = 5120 x 4096 5 = 6144 x 4096
    """
    psMinimumCameraRAW = 0
    psSmallCameraRAW = 1
    psMediumCameraRAW = 2
    psLargeCameraRAW = 3
    psExtraLargeCameraRAW = 4
    psMaximumCameraRAW = 5

class PsCase():
    """
    The case usage for type.
    """
    psNormalCase = 1
    psAllCaps = 2
    psSmallCaps = 3

class PsChangeMode():
    """
    The type of color mode to use. Note:Color images must be changed to grayscale (1) mode before you can change them to bitmap (5) mode.
    """
    psConvertToGrayscale = 1
    psConvertToRGB = 2
    psConvertToCMYK = 3
    psConvertToLab = 4
    psConvertToBitmap = 5
    psConvertToIndexedColor = 6
    psConvertToMultiChannel = 7

class PsChannelType():
    """
    The type of channel: 1: related to document color mode; 2: Alpha channel where color indicates masked area; 3: Alpha channel where color indicates selected area; 4: channel that contains spot colors.
    """
    psComponentChannel = 1
    psMaskedAreaAlphaChannel = 2
    psSelectedAreaAlphaChannel = 3
    psSpotColorChannel = 4

class PsColorBlendMode():
    """
    Controls how pixels in the image are blended.
    """
    psNormalBlendColor = 2
    psDissolveBlend = 3
    psDarkenBlend = 4
    psMultiplyBlend = 5
    psColorBurnBlend = 6
    psLinearBurnBlend = 7
    psLightenBlend = 8
    psScreenBlend = 9
    psColorDodgeBlend = 10
    psLinearDodgeBlend = 11
    psOverlayBlend = 12
    psSoftLightBlend = 13
    psHardLightBlend = 14
    psVividLightBlend = 15
    psLinearLightBlend = 16
    psPinLightBlend = 17
    psDifferenceBlend = 18
    psExclusionBlend = 19
    psHueBlend = 20
    psClearBlend = 25
    psHardMixBlend = 26
    psSubtract = 27
    psDivide = 28

class PsColorModel():
    """
    The color model to use.
    """
    psGrayscaleModel = 1
    psRGBModel = 2
    psCMYKModel = 3
    psLabModel = 4
    psHSBModel = 5
    psNoModel = 50

class PsColorPicker():
    """
    The color picker to use.
    """
    psAdobeColorPicker = 1
    psAppleColorPicker = 2
    psWindowsColorPicker = 3
    psPlugInColorPicker = 4

class PsColorProfileType():
    """
    The color profile type to use to manage this document.
    """
    psNo = 1
    psWorking = 2
    psCustom = 3

class PsColorReductionType():
    """
    The color reduction algorithm option to use.
    """
    psPerceptualReduction = 0
    psSelective = 1
    psAdaptive = 2
    psRestrictive = 3
    psCustomReduction = 4
    psBlackWhiteReduction = 5
    psSFWGrayscale = 6
    psMacintoshColors = 7
    psWindowsColors = 8

class PsColorSpaceType():
    """
    The type of color space to use.
    """
    psAdobeRGB = 0
    psColorMatchRGB = 1
    psProPhotoRGB = 2
    psSRGB = 3

class PsCopyrightedType():
    """
    The copyright status of the document.
    """
    psCopyrightedWork = 1
    psPublicDomain = 2
    psUnmarked = 3

class PsCreateFields():
    """
    The method to use for creating fields.
    """
    psDuplication = 1
    psInterpolation = 2

class PsCropToType():
    """
    The style to use when cropping a page.
    """
    psBoundingBox = 0
    psMediaBox = 1
    psCropBox = 2
    psBleedBox = 3
    psTrimBox = 4
    psArtBox = 5

class PsDCSType():
    """
    The DCS format to use: 1: Does not create a composite file; 2: Creates a grayscale composite file in addition to DCS files; 3: Creates a color composite file in addition to DCS files.
    """
    psNoComposite = 1
    psGrayscaleComposite = 2
    psColorComposite = 3

class PsDepthMapSource():
    """
    What to use for the depth map.
    """
    psNoSource = 1
    psTransparencyChannel = 2
    psLayerMask = 3
    psImageHighlight = 4

class PsDescValueType():
    """
    The value type of an object.
    """
    psIntegerType = 1
    psDoubleType = 2
    psUnitDoubleType = 3
    psStringType = 4
    psBooleanType = 5
    psListType = 6
    psObjectType = 7
    psEnumeratedType = 8
    psReferenceType = 9
    psClassType = 10
    psAliasType = 11
    psRawType = 12
    psLargeIntegerType = 13

class PsDialogModes():
    """
    Controls the type (mode) of dialogs Photoshop displays when running scripts.
    """
    psDisplayAllDialogs = 1
    psDisplayErrorDialogs = 2
    psDisplayNoDialogs = 3

class PsDirection():
    """
    The orientation of the object.
    """
    psHorizontal = 1
    psVertical = 2

class PsDisplacementMapType():
    """
    Describes how the displacement map fits the image if the image is not the same size as the map.
    """
    psStretchToFit = 1
    psTile = 2

class PsDitherType():
    """
    The default type of dithering to use.
    """
    psNoDither = 1
    psDiffusion = 2
    psPattern = 3
    psNoise = 4

class PsDocumentFill():
    """
    The fill of the document.
    """
    psWhite = 1
    psBackgroundColor = 2
    psTransparent = 3

class PsDocumentMode():
    """
    The color mode of the open document.
    """
    psGrayscale = 1
    psRGB = 2
    psCMYK = 3
    psLab = 4
    psBitmap = 5
    psIndexedColor = 6
    psMultiChannel = 7
    psDuotone = 8

class PsEditLogItemsType():
    """
    The history log edit options: 1: Save history log only for the session; 2: Save a concise history log; 3: Save a detailed history log.
    """
    psSessionOnly = 1
    psConcise = 2
    psDetailed = 3

class PsElementPlacement():
    """
    The object’s position in the Layers palette. Note:Not all values are valid for all object types. Please refer to the object property definition in VBScript Interface to make sure you are using a valid value.
    """
    psPlaceInside = 0
    psPlaceAtBeginning = 1
    psPlaceAtEnd = 2
    psPlaceBefore = 3
    psPlaceAfter = 4

class PsEliminateFields():
    """
    The type of fields to eliminate.
    """
    psOddFields = 1
    psEvenFields = 2

class PsExportType():
    """
    The export options to use.
    """
    psIllustratorPaths = 1
    psSaveForWeb = 2

class PsExtensionType():
    """
    The formatting of the extension in the filename.
    """
    psLowercase = 2
    psUppercase = 3

class PsFileNamingType():
    """
    File naming options for the batch command.
    """
    psDocumentNameMixed = 1
    psDocumentNameLower = 2
    psDocumentNameUpper = 3
    psSerialNumber1 = 4
    psSerialNumber2 = 5
    psSerialNumber3 = 6
    psSerialNumber4 = 7
    psSerialLetterLower = 8
    psSerialLetterUpper = 9
    psMmddyy = 10
    psMmdd = 11
    psYyyymmdd = 12
    psYymmdd = 13
    psYyddmm = 14
    psDdmmyy = 15
    psDdmm = 16
    psExtensionLower = 17
    psExtensionUpper = 18

class psFontPreviewType():
    """
    The type size to use for font previews in the type tool font menus.
    """
    psFontPreviewNone = 0
    psFontPreviewSmall = 1
    psFontPreviewMedium = 2
    psFontPreviewLarge = 3
    psFontPreviewExtraLarge = 4
    psFontPreviewHuge = 5

class PsForcedColors():
    """
    The type of colors to be forced (included) into the color table: 2: Pure black and pure white; 3: Red, green, blue, cyan, magenta, yellow, black, and white; 4: the 216 web-safe colors.
    """
    psNoForced = 1
    psBlackWhite = 2
    psPrimaries = 3
    psWeb = 4

class PsFormatOptionsType():
    """
    The option with which to save a JPEG file: 1: Format recognized by most web browsers; 2: Optimized color and a slightly reduced file size; 3: Displays a series of increasingly detailed scans as the image downloads.
    """
    psStandardBaseline = 1
    psOptimizedBaseline = 2
    psProgressive = 3

class PsGalleryConstrainType():
    """
    The type of proportions to constrain for images.
    """
    psConstrainWidth = 1
    psConstrainHeight = 2
    psConstrainBoth = 3

class PsGalleryFontType():
    """
    The fonts to use for the Web photo gallery captions and other text.
    """
    psArial = 1
    psCourierNew = 2
    psHelvetica = 3
    psTimesNewRoman = 4

class PsGallerySecurityTextPositionType():
    """
    The position of the text displayed over gallery images as an antitheft deterrent.
    """
    psCentered = 1
    psUpperLeft = 2
    psLowerLeft = 3
    psUpperRight = 4
    psLowerRight = 5

class PsGallerySecurityTextRotateType():
    """
    The orientation of the text displayed over gallery images as an antitheft deterrent.
    """
    psZero = 1
    psClockwise45 = 2
    psClockwise90 = 3
    psCounterClockwise45 = 4
    psCounterClockwise90 = 5

class PsGallerySecurityType():
    """
    The content to use for text displayed over gallery images as an antitheft deterrent. Note:All types draw from the image’s file information except 2.
    """
    psNoSecurity = 1
    psCustomSecurityText = 2
    psFilename = 3
    psCopyright = 4
    psCaption = 5
    psCredit = 6
    psTitle = 7

class PsGalleryThumbSizeType():
    """
    The size of thumbnail images in the web photo gallery.
    """
    psSmall = 1
    psMedium = 2
    psLarge = 3
    psCustomThumbnail = 4

class PsGeometry():
    """
    Geometric options for shapes, such as the iris shape in the Lens Blur Filter.
    """
    psTriangle = 0
    psPentagon = 1
    psHexagon = 2
    psSquareGeometry = 3
    psHeptagon = 4
    psOctagon = 5

class PsGridLineStyle():
    """
    The line style for the nonprinting grid displayed over images.
    """
    psGridSolidLine = 1
    psGridDashedLine = 2
    psGridDottedLine = 3

class PsGridSize():
    """
    The value of grid line spacing.
    """
    psNoGrid = 1
    psSmallGrid = 2
    psMediumGrid = 3
    psLargeGrid = 4

class PsGuideLineStyle():
    """
    The line style for nonprinting guides displayed over images.
    """
    psGuideSolidLine = 1
    psGuideDashedLine = 2

class PsIllustratorPathType():
    """
    The paths to export.
    """
    psDocumentBounds = 1
    psAllPaths = 2
    psNamedPath = 3

class PsIntent():
    """
    The rendering intent to use when converting from one color space to another.
    """
    psPerceptual = 1
    psSaturation = 2
    psRelativeColorimetric = 3
    psAbsoluteColorimetric = 4

class PsJavaScriptExecutionMode():
    """
    The debugging behavior to use when executing a JavaScript.
    """
    psNeverShowDebugger = 1
    psDebuggerOnError = 2
    psBeforeRunning = 3

class PsJustification():
    """
    The placement of paragraph text within the bounding box.
    """
    psLeft = 1
    psCenter = 2
    psRight = 3
    psLeftJustified = 4
    psCenterJustified = 5
    psRightJustified = 6
    psFullyJustified = 7

class PsLanguage():
    """
    The language to use.
    """
    psEnglishUSA = 1
    psEnglishUK = 2
    psFrench = 3
    psCanadianFrench = 4
    psFinnish = 5
    psGerman = 6
    psOldGerman = 7
    psSwissGerman = 8
    psItalian = 9
    psNorwegian = 10
    psNynorskNorwegian = 11
    psPortuguese = 12
    psBrazillianPortuguese = 13
    psSpanish = 14
    psSwedish = 15
    psDutch = 16
    psDanish = 17

class PsLayerCompressionType():
    """
    Compression methods for data for pixels in layers.
    """
    psRLELayerCompression = 1
    psZIPLayerCompression = 2

class PsLayerKind():
    """
    The kind of ArtLayer object.
    """
    psNormalLayer = 1
    psTextLayer = 2
    psSolidFillLayer = 3
    psGradientFillLayer = 4
    psPatternfillLayer = 5
    psLevelsLayer = 6
    psCurvesLayer = 7
    psColorBalanceLayer = 8
    psBrightnessContrastLayer = 9
    psHueSaturationLayer = 10
    psSelectiveColorLayer = 11
    psChannelMixerLayer = 12
    psGradientMapLayer = 13
    psInversionLayer = 14
    psThresholdLayer = 15
    psPosterizeLayer = 16
    psSmartObjectLayer = 17
    psPhotoFilterLayer = 18
    psExposureLayer = 19
    psLayer3D = 20
    psVideoLayer = 21
    psBlackAndWhiteLayer = 22
    psVibrance = 23

class PsLayerType():
    """
    The kind of layer object.
    """
    psArtLayer = 1
    psLayerSet = 2

class PsLensType():
    """
    The type of lens to use.
    """
    psZoomLens = 1
    psPrime35 = 2
    psPrime105 = 3
    psMoviePrime = 5

class PsMagnificationType():
    """
    The type of magnification to use when viewing an image.
    """
    psActualSize = 0
    psFitPage = 1

class PsMatteType():
    """
    The color to use for matting.
    """
    psNoMatte = 1
    psForegroundColorMatte = 2
    psBackgroundColorMatte = 3
    psWhiteMatte = 4
    psBlackMatte = 5
    psSemiGray = 6
    psNetscapeGrayMatte = 7

class PsMeasurementRange():
    """
    The measurement to take action upon
    """
    psAllMeasurements = 1
    psActiveMeasurements = 2

class PsMeasurementSource():
    """
    The source for recording measurements
    """
    psMeasureSelection = 1
    psMeasureCountTool = 2
    psMeasureRulerTool = 3

class PsNewDocumentMode():
    """
    The color profile to use for the document.
    """
    psNewGray = 1
    psNewRGB = 2
    psNewCMYK = 3
    psNewLab = 4
    psNewBitmap = 5

class PsNoiseDistribution():
    """
    Distribution method to use when applying an Add Noise filter.
    """
    psUniformNoise = 1
    psGaussianNoise = 2

class PsOffsetUndefinedAreas():
    """
    Method to use to fill the empty space left by offsetting a an image or selection.
    """
    psOffsetSetToLayerFill = 1
    psOffsetWraparound = 2
    psOffsetRepeatEdgePixels = 3

class PsOpenDocumentMode():
    """
    The color profile to use.
    """
    psOpenGray = 1
    psOpenRGB = 2
    psOpenCMYK = 3
    psOpenLab = 4

class PsOpenDocumentType():
    """
    The format in which to open a document. Note: psPhotoCDOpen (8) is deprecated. Kodak PhotoCD is now found in the Goodies folder on the Adobe Photoshop Install DVD. Note:The psDICOMOpen (33) option is for the Extended version only.
    """
    psPhotoshopOpen = 1
    psBMPOpen = 2
    psCompuServeGIFOpen = 3
    psPhotoshopEPSOpen = 4
    psFilmstripOpen = 5
    psJPEGOpen = 6
    psPCXOpen = 7
    psPhotoshopPDFOpen = 8
    psPhotoCDOpen = 9
    psPICTFileFormatOpen = 10
    psPICTResourceFormatOpen = 11
    psPixarOpen = 12
    psPNGOpen = 13
    psRawOpen = 14
    psScitexCTOpen = 15
    psTargaOpen = 16
    psTIFFOpen = 17
    psPhotoshopDCS_1Open = 18
    psPhotoshopDCS_2Open = 19
    psPDFOpen = 21
    psEPSOpen = 22
    psEPSPICTPreviewOpen = 23
    psEPSTIFFPreviewOpen = 24
    psAliasPIXOpen = 25
    psElectricImageOpen = 26
    psPortableBitmapOpen = 27
    psWavefrontRLAOpen = 28
    psSGIRGBOpen = 29
    psSoftImageOpen = 30
    psWirelessBitmapOpen = 31
    psCameraRAWOpen = 32
    psDICOMOpen = 33

class PsOperatingSystem():
    """
    The operating system.
    """
    psOS2 = 1
    psWindows = 2

class PsOrientation():
    """
    The page orientation.
    """
    psLandscape = 1
    psPortrait = 2

class PsOtherPaintingCursors():
    """
    The pointer for the following tools: Eraser, Pencil, Paintbrush, Healing Brush, Rubber Stamp, Pattern Stamp, Smudge, Blur, Sharpen, Dodge, Burn, Sponge.
    """
    psStandardOther = 1
    psPreciseOther = 2

class PsPaintingCursors():
    """
    The pointer for the following tools: Marquee, Lasso, Polygonal Lasso, Magic Wand, Crop, Slice, Patch Eyedropper, Pen, Gradient, Line, Paint Bucket, Magnetic Lasso, Magnetic Pen, Freeform Pen, Measure, Color Sampler.
    """
    psStandard = 1
    psPrecise = 2
    psBrushsize = 3

class PsPaletteType():
    """
    The palette type to use.
    """
    psExact = 1
    psMacOSPalette = 2
    psUniform = 5
    psLocalPerceptual = 6
    psLocalSelective = 7
    psLocalAdaptive = 8
    psMasterPerceptual = 9
    psMasterSelective = 10
    psMasterAdaptive = 11
    psPreviousPalette = 12

class PsPathKind():
    """
    The type of path.
    """
    psNormalPath = 1
    psClippingPath = 2
    psWorkPath = 3
    psVectorMask = 4
    psTextMask = 5

class PsPDFCompatibilityType():
    """
    The PDF version to make the document compatible with.
    """
    psPDF13 = 1
    psPDF14 = 2
    psPDF15 = 3
    psPDF16 = 4

class PsPDFEncoding():
    """
    Encoding and compression options to use when saving a document in PDF format.
    """
    psPDFNone = 0
    psPDFZip = 1
    psPDFJPEG = 2
    psPDFPDFZip4Bit = 3
    psPDFJPEGHIGH = 4
    psPDFJPEGMEDHIGH = 5
    psPDFJPEGMED = 6
    psPDFJPEGMEDLOW = 7
    psPDFJPEGLOW = 8
    psPDFJPEG2000High = 9
    psPDFJPEG2000MEDHIGH = 10
    psPDFJPEG2000MED = 11
    psPDFJPEG2000MEDLOW = 12
    psPDFJPEG2000LOW = 13
    psPDFJPEG2000LOSSLESS = 14

class PsPDFResampleType():
    """
    The down sample method to use.
    """
    psNoResample = 0
    psPDFAverage = 1
    psPDFSubSample = 2
    psPDFBicubic = 3

class PsPDFStandardType():
    """
    The PDF standard to make the document compatible with.
    """
    psNoStandard = 0
    psPDFX1A2001 = 1
    psPDFX1A2003 = 2
    psPDFX32002 = 3
    psPDFX32003 = 4

class PsPhotoCDColorSpace():
    """
    The color space to use when creating a Photo CD. Note:Deprecated for Adobe Photoshop. Kodak PhotoCD is now found in the Goodies folder on the Adobe Photoshop Install DVD.
    """
    psRGB8 = 1
    psRGB16 = 2
    psLab8 = 3
    psLab16 = 4

class PsPhotoCDSize():
    """
    The pixel dimensions of the image. psMinimumPhotoCD = 64x96 psSmallPhotoCD = 128x192 psMediumPhotoCD = 256x384 psLargePhotoCD = 512x768 psExtralargePhotoCD = 1024x1536 psMaximumPhotoCD = 2048x3072 Note:Deprecated for Adobe Photoshop. Kodak PhotoCD is now found in the Goodies folder on the Adobe Photoshop Install DVD.
    """
    psMinimumPhotoCD = 1
    psSmallPhotoCD = 2
    psMediumPhotoCD = 3
    psLargePhotoCD = 4
    psExtralargePhotoCD = 5
    psMaximumPhotoCD = 6

class PsPICTBitsPerPixels():
    """
    The number of bits per pixel to use when compression a PICT file. Note:Use 16 or 32 for RGB images; use 2, 4, or 8 for bitmap and grayscale images.
    """
    psPICTTwoBits = 2
    psPICTFourBits = 4
    psPICTEightBits = 8
    psPICTSixteenBits = 16
    psPICTThirtyTwoBits = 32

class PsPICTCompression():
    """
    The type of compression to use when saving an image as a PICT file.
    """
    psNoPICTCompression = 1
    psJPEGLowPICT = 2
    psJPEGMediumPICT = 4
    psJPEGHighPICT = 5
    psJPEGMaximumPICT = 6

class PsPicturePackageTextType():
    """
    The function or meaning of text in a Picture Package.
    """
    psNoText = 1
    psUserText = 2
    psFilenameText = 3
    psCopyrightText = 4
    psCaptionText = 5
    psCreditText = 6
    psOriginText = 7

class PsPointKind():
    """
    The role a PathPoint plays in a PathItem.
    """
    psSmoothPoint = 1
    psCornerPoint = 2

class PsPointType():
    """
    The kind of measurement to use for type points: 1 = 72 points/inch; 2 = 72.27 points/inch.
    """
    psPostScriptPoints = 1
    psTraditionalPoints = 2

class PsPolarConversionType():
    """
    The method of polar distortion to use.
    """
    psRectangularToPolar = 1
    psPolarToRectangular = 2

class PsPreviewType():
    """
    The type of image to use as a low-resolution preview in the destination application.
    """
    psNoPreview = 1
    psMonochromeTIFF = 2
    psEightbitTIFF = 3

class PsPurgeTarget():
    """
    Cache to be targeted in a purge operation.
    """
    psUndoCaches = 1
    psHistoryCaches = 2
    psClipboardCache = 3
    psAllCaches = 4

class PsQueryStateType():
    """
    Permission state for queries.
    """
    psAlways = 1
    psAsk = 2
    psNever = 3

class PsRadialBlurMethod():
    """
    The blur method to use.
    """
    psSpin = 1
    psZoom = 2

class PsRadialBlurQuality():
    """
    The smoothness or graininess of the blurred image.
    """
    psRadialBlurDraft = 1
    psRadialBlurGood = 2
    psRadialBlurBest = 3

class PsRasterizeType():
    """
    The layer element to rasterize.
    """
    psTextContents = 1
    psShape = 2
    psFillContent = 3
    psLayerClippingPath = 4
    psEntireLayer = 5
    psLinkedLayers = 6

class PsReferenceFormType():
    """
    The type of an ActionReference object.
    """
    psReferenceNameType = 1
    psReferenceIndexType = 2
    psReferenceIdentifierType = 3
    psReferenceOffsetType = 4
    psReferenceEnumeratedType = 5
    psReferencePropertyType = 6
    psReferenceClassType = 7

class PsResampleMethod():
    """
    The method to use for image interpolation.
    """
    psNoResampling = 1
    psNearestNeighbor = 2
    psBilinear = 3
    psBicubic = 4
    psBicubicSharper = 5
    psBicubicSmoother = 6
    psBicubicAutomatic = 7
    psAutomatic = 8
    psPreserveDetails = 9

class PsRippleSize():
    """
    The undulation size to use.
    """
    psSmallRipple = 1
    psMediumRipple = 2
    psLargeRipple = 3

class PsSaveBehavior():
    """
    The application’s behavior when a Save method is called.
    """
    psNeverSave = 1
    psAlwaysSave = 2
    psAskWhenSaving = 3

class PsSaveDocumentType():
    """
    The format in which to save a document.
    """
    psPhotoshopSave = 1
    psBMPSave = 2
    psCompuServeGIFSave = 3
    psPhotoshopEPSSave = 4
    psJPEGSave = 6
    psPCXSave = 7
    psPhotoshopPDFSave = 8
    psPICTFileFormatSave = 10
    psPixarSave = 12
    psPNGSave = 13
    psRawSave = 14
    psScitexCTSave = 15
    psTargaSave = 16
    psTIFFSave = 17
    psPhotoshopDCS_1Save = 18
    psPhotoshopDCS_2Save = 19
    psAliasPIXSave = 25
    psElectricImageSave = 26
    psPortableBitmapSave = 27
    psWavefrontRLASave = 28
    psSGIRGBSave = 29
    psSoftImageSave = 30
    psWirelessBitmapSave = 31

class PsSaveEncoding():
    """
    The type of encoding to use when saving a file.
    """
    psBinary = 1
    psJPEGLow = 2
    psAscii = 3
    psJPEGMedium = 4
    psJPEGHigh = 5
    psJPEGMaximum = 6

class PsSaveLogItemsType():
    """
    The location of history log data.
    """
    psMetadata = 1
    psLogFile = 2
    psLogFileAndMetadata = 3

class PsSaveOptions():
    """
    The save options to use when the Close method is called to close a document.
    """
    psSaveChanges = 1
    psDoNotSaveChanges = 2
    psPromptToSaveChanges = 3





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .gallerycustomcoloroptions import GalleryCustomColorOptions
    from .application import Application
    from .galleryimagesoptions import GalleryImagesOptions
    from .gallerythumbnailoptions import GalleryThumbnailOptions
    from .gallerybanneroptions import GalleryBannerOptions
    from .gallerysecurityoptions import GallerySecurityOptions

class GalleryOptions():
    """
    Options that can be specifie d for a Web photo gallery. Tip: You can preserve default values for many GalleryOptions properties by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def AddSizeAttributes(self) -> bool:
        """
        Read-write. Indicates whether width and height attributes for images will be added. Default: true.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def BannerOptions(self) -> GalleryBannerOptions:
        """
        Read-write. The options related to banner settings.
        """
        ...

    @property
    def CustomColorOptions(self) -> GalleryCustomColorOptions:
        """
        Read-write. The options related to custom color settings.
        """
        ...

    @property
    def EmailAddress(self) -> str:
        """
        Read-write. The email address to show on the Web page.
        """
        ...

    @property
    def ImagesOptions(self) -> GalleryImagesOptions:
        """
        Read-write. The options related to images settings.
        """
        ...

    @property
    def IncludeSubFolders(self) -> bool:
        """
        Read-write. Indication of whether to include all files found in sub folders of the input folder. Default: true.
        """
        ...

    @property
    def LayoutStyle(self) -> str:
        """
        Read-write. The style to use for laying out the Web page. Default: Centered Frame 1 - Basic.
        """
        ...

    @property
    def PreserveAllMetadata(self) -> bool:
        """
        Read-write. Indicates whether to save metadata. Default: false.
        """
        ...

    @property
    def SecurityOptions(self) -> GallerySecurityOptions:
        """
        Read-write. The options related to security settings.
        """
        ...

    @property
    def ThumbnailOptions(self) -> GalleryThumbnailOptions:
        """
        Read-write. The options related to thumbnail image settings.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GalleryOptions object.
        """
        ...

    @property
    def UseShortExtension(self) -> bool:
        """
        Read-write. Indicates whether the short Web page extension .htm or Number (Long) Web page extension .html will be used. Default: true.
        """
        ...

    @property
    def UseUTF8Encoding(self) -> bool:
        """
        Read-write. Indicates whether the Web page should use UTF-8 encoding. Default: false.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .numberlong import NumberLong
    from .channel import Channel
    from .application import Application
    from .document import Document

class Channels():
    """
    The collection of Channel objects in the document. See ‘Channel ’ on page 43.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the Channels collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Channels object.
        """
        ...

    def Add(self) -> Channel:
        """
        Creates a new Channel object.
        """
        ...

    def Index(self, ItemPtr:Channel) -> int:
        """
        Gets the index of the specified Channel object.
        """
        ...

    def Item(self, ItemKey:NumberLong) -> Channel:
        """
        Gets an element from the Channels collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes all Channel objects from the Channels collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pssaveencoding import PsSaveEncoding
    from .application import Application
    from .pspreviewtype import PsPreviewType

class EPSSaveOptions():
    """
    Options that can be specified when saving a document in EPS format. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in this document.
        """
        ...

    @property
    def Encoding(self) -> PsSaveEncoding:
        """
        Read-write. The type of encoding to use. Default: 1.
        """
        ...

    @property
    def HalftoneScreen(self) -> bool:
        """
        Read-write. Indicates whether to include the halftone screen. Default: false.
        """
        ...

    @property
    def Interpolation(self) -> bool:
        """
        Read-write. Indicates whether to use image interpolation. Default: false.
        """
        ...

    @property
    def Preview(self) -> PsPreviewType:
        """
        Read-write. The preview type.
        """
        ...

    @property
    def PsColorManagement(self) -> bool:
        """
        Read-write. Indicates whether to use Postscript color management. Default: false.
        """
        ...

    @property
    def TransferFunction(self) -> bool:
        """
        Read-write. Indicates whether to include the Transfer functions to compensate for dot gain between the image and film. Default: false.
        """
        ...

    @property
    def TransparentWhites(self) -> bool:
        """
        Read-write. Indicates whether to display white areas as transparent. Note:Valid only when Document.Mode = 5. See ‘Mode’ on page 61 (in the Properties table of the Document object) or ‘ChangeMode’ on page 63 (in the Methods table of the Document object).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced EPSSaveOptions object.
        """
        ...

    @property
    def VectorData(self) -> bool:
        """
        Read-write. Indicates whether to include vector data. Note:Valid only if the document includes vector data (text).
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psgridsize import PsGridSize
    from .pscolorpicker import PsColorPicker
    from .pspaintingcursors import PsPaintingCursors
    from .pspointtype import PsPointType
    from .psresamplemethod import PsResampleMethod
    from .psunits import PsUnits
    from .pssavelogitemstype import PsSaveLogItemsType
    from .psguidelinestyle import PsGuideLineStyle
    from .psfontpreviewtype import psFontPreviewType
    from .pstypeunits import PsTypeUnits
    from .application import Application
    from .psgridlinestyle import PsGridLineStyle
    from .psquerystatetype import PsQueryStateType
    from .pssavebehavior import PsSaveBehavior
    from .psotherpaintingcursors import PsOtherPaintingCursors
    from .pseditlogitemstype import PsEditLogItemsType

class Preferences():
    """
    Options to define for the Preferences property of the Application object. See ‘Preferences ’ on page 17 (in the Properties table for the Application object).Note: Defining the Preferences properties is basically equivalent to selecting Edit > Preferences (Windows) or Photoshop > Preferences in the Adob e Photoshop application. For explanations of individual settings, please refer to Adobe Photoshop Help. 
    """
    @property
    def AdditionalPluginFolder(self) -> str:
        """
        Read-write. The path to an additional plug-in folder. Note:Valid only when UseAdditionalPluginFolder = true. See UseAdditionalPluginFolder.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def AskBeforeSavingLayeredTIFF(self) -> bool:
        """
        Read-write. Indicates whether to ask the user to verify layer preservation options when saving a file in TIFF format.
        """
        ...

    @property
    def AutoUpdateOpenDocuments(self) -> bool:
        """
        Read-write. Indicates whether to automatically update open documents.
        """
        ...

    @property
    def BeepWhenDone(self) -> bool:
        """
        Read-write. Indicates whether to beep when a process finishes.
        """
        ...

    @property
    def ColorChannelsInColor(self) -> bool:
        """
        Read-write. Indicates whether to display component channels in the Channels palette in color.
        """
        ...

    @property
    def ColorPicker(self) -> PsColorPicker:
        """
        Read-write.
        """
        ...

    @property
    def ColumnGutter(self) -> float:
        """
        Read-write. The width of the column gutters (in points). (0.1 - 600.0).
        """
        ...

    @property
    def ColumnWidth(self) -> float:
        """
        Read-write. Column width (in points) (0.1 - 600.0).
        """
        ...

    @property
    def CreateFirstSnapshot(self) -> bool:
        """
        Read-write. Indicates whether to automatically make the first snapshot when a new document is created.
        """
        ...

    @property
    def DynamicColorSliders(self) -> bool:
        """
        Read-write. Indicates whether dynamic color sliders appear in the Color palette.
        """
        ...

    @property
    def EditLogItems(self) -> PsEditLogItemsType:
        """
        Read-write. The options for editing history log items. Note:Valid only when UseHistoryLog = true. See UseHistoryLog.
        """
        ...

    @property
    def ExportClipboard(self) -> bool:
        """
        Read-write. Indicates whether to retain Adobe Photoshop contents on the clipboard after you exit the application.
        """
        ...

    @property
    def FontPreviewSize(self) -> psFontPreviewType:
        """
        Read-write. Indicates whether to show font previews in the type tool font menus.
        """
        ...

    @property
    def GamutWarningOpacity(self) -> float:
        """
        Read-write. (0 - 100 as percent).
        """
        ...

    @property
    def GridSize(self) -> PsGridSize:
        """
        Read-write. The size to use for squares in the grid.
        """
        ...

    @property
    def GridStyle(self) -> PsGridLineStyle:
        """
        Read-write. The formatting style for non-printing grid lines.
        """
        ...

    @property
    def GridSubDivisions(self) -> int:
        """
        Read-write. (1 - 100)
        """
        ...

    @property
    def GuideStyle(self) -> PsGuideLineStyle:
        """
        Read-write. The formatting style for non-printing guide lines.
        """
        ...

    @property
    def ImageCacheLevels(self) -> int:
        """
        Read-write. The number of images to hold in the cache (1 - 8).
        """
        ...

    @property
    def ImagePreviews(self) -> PsSaveBehavior:
        """
        Read-write. The behavior mode to use when saving files.
        """
        ...

    @property
    def Interpolation(self) -> PsResampleMethod:
        """
        Read-write. The method to use to assign color values to any new pixels created when an image is resampled or resized.
        """
        ...

    @property
    def KeyboardZoomResizesWindows(self) -> bool:
        """
        Read-write. Indicates whether to automatically resize the window when zooming in or out using keyboard shortcuts.
        """
        ...

    @property
    def MaximizeCompatibility(self) -> PsQueryStateType:
        """
        Read-write. The behavior to use to check whether to maximize compatibility when opening Adobe Photoshop (PSD) files.
        """
        ...

    @property
    def MaxRAMuse(self) -> int:
        """
        Read-write. The maximum percentage of available RAM used by Adobe Photoshop (5 - 100).
        """
        ...

    @property
    def NonLinearHistory(self) -> bool:
        """
        Read-write. Indicates whether to allow non-linear history.
        """
        ...

    @property
    def NumberOfHistoryStates(self) -> int:
        """
        Read-write. The number of history states to preserve (1 - 100).
        """
        ...

    @property
    def OtherCursors(self) -> PsOtherPaintingCursors:
        """
        Read-write. The type of pointer to use.
        """
        ...

    @property
    def PaintingCursors(self) -> PsPaintingCursors:
        """
        Read-write. The type of pointer to use.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-write. The Preferences object's container.
        """
        ...

    @property
    def PixelDoubling(self) -> bool:
        """
        Read-write. Indicates whether to halve the resolution or (double the size of pixels) to make previews display more quickly.
        """
        ...

    @property
    def PointSize(self) -> PsPointType:
        """
        Read-write. The point/pica size.
        """
        ...

    @property
    def RecentFileListLength(self) -> int:
        """
        Read-write. The number of items in the recent file list (0 - 30).
        """
        ...

    @property
    def RulerUnits(self) -> PsUnits:
        """
        Read-write. The unit the scripting system will use when receiving and returning values.
        """
        ...

    @property
    def SaveLogItems(self) -> PsSaveLogItemsType:
        """
        Read-write. The options for saving the history items.
        """
        ...

    @property
    def SaveLogItemsFile(self) -> str:
        """
        Read-write. The path to the history log file.
        """
        ...

    @property
    def SavePaletteLocations(self) -> bool:
        """
        Read-write. Indicates whether to make new palette locations the default location.
        """
        ...

    @property
    def ShowAsianTextOptions(self) -> bool:
        """
        Read-write. Indicates whether to display Asian text options in the Paragraph palette.
        """
        ...

    @property
    def ShowEnglishFontNames(self) -> bool:
        """
        Read-write. Indicates whether to list Asian font names in English.
        """
        ...

    @property
    def ShowSliceNumber(self) -> bool:
        """
        Read-write. Indicates whether to display slice numbers in the document window when using the Slice tool.
        """
        ...

    @property
    def ShowToolTips(self) -> bool:
        """
        Read-write. Indicates whether to show pop up definitions on mouse over.
        """
        ...

    @property
    def SmartQuotes(self) -> bool:
        """
        Read-write. Indicates whether to use curly or straight quote marks.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Preferences object.
        """
        ...

    @property
    def TypeUnits(self) -> PsTypeUnits:
        """
        Read-write. The unit type-size that the numeric inputs are assumed to represent.
        """
        ...

    @property
    def UseAdditionalPluginFolder(self) -> bool:
        """
        Read-write. Indicates whether to use an additional folder for compatible plug-ins stored with a different application.
        """
        ...

    @property
    def UseHistoryLog(self) -> bool:
        """
        Read-write. Indicates whether to create a log file for history states.
        """
        ...

    @property
    def UseLowerCaseExtension(self) -> bool:
        """
        Read-write. Indicates whether the file extension should be lowercase.
        """
        ...

    @property
    def UseShiftKeyForToolSwitch(self) -> bool:
        """
        Read-write. Indicates whether to enable cycling through a set of hidden tools.
        """
        ...

    @property
    def UseVideoAlpha(self) -> bool:
        """
        Read-write. Indicates whether to enable Adobe Photoshop to send transparency information to your computer’s video board. (Requires hardware support.)
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class RGBColor():
    """
    The definition of a color in RGB color mode.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Blue(self) -> float:
        """
        Read-write. The blue color value ( 0.0 - 255.0; default: 255.0).
        """
        ...

    @property
    def Green(self) -> float:
        """
        Read-write. The green color value (0.0 - 255.0; default: 255.0).
        """
        ...

    @property
    def HexValue(self) -> str:
        """
        Read-write. The hex representation of the color.
        """
        ...

    @property
    def Red(self) -> float:
        """
        Read-write. The red color value (0.0 - 255.0; default: 255.0).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced RGBColor object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .rgbcolor import RGBColor
    from .application import Application

class GalleryCustomColorOptions():
    """
    Options that define the customColorOptions property of the GalleryOptions object. See ‘GalleryOptions ’ on page 82.Tip: You can preserve default values for many GalleryCustomColorOptions properties by setting the GalleryOptions property PreserveAllMetadata to true or by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def ActiveLinkColor(self) -> RGBColor:
        """
        Read-write. The color to use to indicate an active link.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def BackgroundColor(self) -> RGBColor:
        """
        Read-write. The background color.
        """
        ...

    @property
    def BannerColor(self) -> RGBColor:
        """
        Read-write. The banner color.
        """
        ...

    @property
    def LinkColor(self) -> RGBColor:
        """
        Read-write. The color to use to indicate a link.
        """
        ...

    @property
    def TextColor(self) -> RGBColor:
        """
        Read-write. The text color.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GalleryCustomColorOptions object.
        """
        ...

    @property
    def VisitedLinkColor(self) -> RGBColor:
        """
        Read-write. The color to use to indicate a visited link.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .nothing import Nothing
    from .application import Application
    from .document import Document
    from .artlayer import ArtLayer

class ArtLayers():
    """
    The collection of ArtLayer objects in the document. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the ArtLayers collection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ArtLayers object.
        """
        ...

    def Add(self) -> ArtLayer:
        """
        Creates a new ArtLayer in the document.
        """
        ...

    def Index(self, ItemPtr:ArtLayer) -> int:
        """
        Gets the index of the ArtLayer into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> ArtLayer:
        """
        Gets an element from the ArtLayers collection.
        """
        ...

    def RemoveAll(self) -> Nothing:
        """
        Removes all elements from the ArtLayers collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psdescvaluetype import PsDescValueType
    from .actionreference import ActionReference
    from .actiondescriptor import ActionDescriptor

class ActionList():
    """
    This object provides an array-style mechanism for stor ing dta. It can be used for low-leve access into Photoshop.This object is ideal when storing data of the same type. All items in the list must be the same type.You can use the "put" methods, such as putBoolean(), to append new elements, and can clear the entire list using clear(), but cannoth otherwise modify the list. Note: The actionList object is part of the Action Manager functionality. For details on using the Action Manager, see the Photoshop Scripting Guide.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of commands that comprise the action.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced actionList object.
        """
        ...

    def Clear(self) -> None:
        """
        Clears the list.
        """
        ...

    def GetBoolean(self, Index:int) -> bool:
        """
        Gets the value of a list item of type boolean.
        """
        ...

    def GetClass(self, Index:int) -> int:
        """
        Gets the value of a list item of type class.
        """
        ...

    def GetDouble(self, Index:int) -> float:
        """
        Gets the value of a list item of type double.
        """
        ...

    def GetEnumerationType(self, Index:int) -> int:
        """
        Gets the enumeration type of a list item.
        """
        ...

    def GetEnumerationValue(self, Index:int) -> int:
        """
        Gets the enumeration value of a list item.
        """
        ...

    def GetInteger(self, Index:int) -> int:
        """
        Gets the value of a list item of type integer.
        """
        ...

    def GetLargeInteger(self, Index:int) -> int:
        """
        Gets the value of a list item of type large integer.
        """
        ...

    def GetList(self, Index:int):
        """
        Gets the value of a list item of type list.
        """
        ...

    def GetObjectType(self, Index:int) -> int:
        """
        Gets the class ID of a list item of type object.
        """
        ...

    def GetObjectValue(self, Index:int) -> ActionDescriptor:
        """
        Gets the value of a list item of type object.
        """
        ...

    def GetPath(self, Index:int) -> str:
        """
        Gets the value of a list item of type Alias. Retuns a String that represents a file path.
        """
        ...

    def GetReference(self, Index:int) -> ActionReference:
        """
        Gets the value of a list item of type ActionReference.
        """
        ...

    def GetString(self, Index:int) -> str:
        """
        Gets the value of a list item of type String.
        """
        ...

    def GetType(self, Index:int) -> PsDescValueType:
        """
        Gets the type of a list item.
        """
        ...

    def GetUnitDoubleType(self, Index:int) -> int:
        """
        Gets the unit value type of a list item of type Double.
        """
        ...

    def GetUnitDoubleValue(self, Index:int) -> float:
        """
        Gets the unit value of a list item of type double.
        """
        ...

    def PutBoolean(self, Value:bool) -> None:
        """
        Sets the value to either true or false.
        """
        ...

    def PutClass(self, Value:int) -> None:
        """
        Sets the class or data type.
        """
        ...

    def PutDouble(self, Value:float) -> None:
        """
        Sets the value type as a double.
        """
        ...

    def PutEnumerated(self, EnumType:int, Value:int) -> None:
        """
        Sets the value type as an enumerated, or constant, value.
        """
        ...

    def PutInteger(self, Value:int) -> None:
        """
        Sets the value of a list item of type integer.
        """
        ...

    def PutLargeInteger(self, Value:int) -> None:
        """
        Sets the value of a list item of type large integer.
        """
        ...

    def PutList(self, Value) -> None:
        """
        Sets the value of a list item of type list or array.
        """
        ...

    def PutObject(self, ClassID:int, Value:ActionDescriptor) -> None:
        """
        Sets the value of a list item of type object.
        """
        ...

    def PutPath(self, Value:str) -> None:
        """
        Sets the value of a list item of type path. The Value parameter takes a String that represents a file path.
        """
        ...

    def PutReference(self, Value:ActionReference) -> None:
        """
        Sets the value of a list item whose type a reference to an object created in the script.
        """
        ...

    def PutString(self, Value:str) -> None:
        """
        Sets the value of a list item of type String.
        """
        ...

    def PutUnitDouble(self, UnitID:int, Value:float) -> None:
        """
        Sets the value of a list item of type unit value represented as a double.
        """
        ...




from .actiondescriptor import ActionDescriptor
from .actionlist import ActionList
from .actionreference import ActionReference
from .application import Application
from .artlayer import ArtLayer
from .artlayers import ArtLayers
from .batchoptions import BatchOptions
from .bitmapconversionoptions import BitmapConversionOptions
from .bmpsaveoptions import BMPSaveOptions
from .camerarawopenoptions import CameraRAWOpenOptions
from .channel import Channel
from .channels import Channels
from .cmykcolor import CMYKColor
from .colorsampler import ColorSampler
from .colorsamplers import ColorSamplers
from .contactsheetoptions import ContactSheetOptions
from .countitem import CountItem
from .countitems import CountItems
from .dicomopenoptions import DICOMOpenOptions
from .document import Document
from .documentinfo import DocumentInfo
from .documents import Documents
from .epsopenoptions import EPSOpenOptions
from .epssaveoptions import EPSSaveOptions
from .exportoptionsillustrator import ExportOptionsIllustrator
from .exportoptionssaveforweb import ExportOptionsSaveForWeb
from .gallerybanneroptions import GalleryBannerOptions
from .gallerycustomcoloroptions import GalleryCustomColorOptions
from .galleryimagesoptions import GalleryImagesOptions
from .galleryoptions import GalleryOptions
from .gallerysecurityoptions import GallerySecurityOptions
from .gallerythumbnailoptions import GalleryThumbnailOptions
from .gifsaveoptions import GIFSaveOptions
from .graycolor import GrayColor
from .historystate import HistoryState
from .historystates import HistoryStates
from .hsbcolor import HSBColor
from .indexedconversionoptions import IndexedConversionOptions
from .jpegsaveoptions import JPEGSaveOptions
from .labcolor import LabColor
from .layercomp import LayerComp
from .layercomps import LayerComps
from .layers import Layers
from .layerset import LayerSet
from .layersets import LayerSets
from .measurementlog import MeasurementLog
from .measurementscale import MeasurementScale
from .nocolor import NoColor
from .notifier import Notifier
from .notifiers import Notifiers
from .pathitem import PathItem
from .pathitems import PathItems
from .pathpoint import PathPoint
from .pathpointinfo import PathPointInfo
from .pathpoints import PathPoints
from .pdfopenoptions import PDFOpenOptions
from .pdfsaveoptions import PDFSaveOptions
from .photocdopenoptions import PhotoCDOpenOptions
from .photoshopsaveoptions import PhotoshopSaveOptions
from .pictfilesaveoptions import PICTFileSaveOptions
from .picturepackageoptions import PicturePackageOptions
from .pixarsaveoptions import PixarSaveOptions
from .pngsaveoptions import PNGSaveOptions
from .preferences import Preferences
from .presentationoptions import PresentationOptions
from .rawformatopenoptions import RawFormatOpenOptions
from .rawsaveoptions import RawSaveOptions
from .rgbcolor import RGBColor
from .selection import Selection
from .sgirgbsaveoptions import SGIRGBSaveOptions
from .solidcolor import SolidColor
from .subpathinfo import SubPathInfo
from .subpathitem import SubPathItem
from .subpathitems import SubPathItems
from .targasaveoptions import TargaSaveOptions
from .textfont import TextFont
from .textfonts import TextFonts
from .textitem import TextItem
from .tiffsaveoptions import TiffSaveOptions
from .xmpmetadata import XMPMetadata

class PhotoshopObjectModel():
    def __init__(self):
        self.ActionDescriptor = ActionDescriptor()
        self.ActionList = ActionList()
        self.ActionReference = ActionReference()
        self.Application = Application()
        self.ArtLayer = ArtLayer()
        self.ArtLayers = ArtLayers()
        self.BatchOptions = BatchOptions()
        self.BitmapConversionOptions = BitmapConversionOptions()
        self.BMPSaveOptions = BMPSaveOptions()
        self.CameraRAWOpenOptions = CameraRAWOpenOptions()
        self.Channel = Channel()
        self.Channels = Channels()
        self.CMYKColor = CMYKColor()
        self.ColorSampler = ColorSampler()
        self.ColorSamplers = ColorSamplers()
        self.ContactSheetOptions = ContactSheetOptions()
        self.CountItem = CountItem()
        self.CountItems = CountItems()
        self.DICOMOpenOptions = DICOMOpenOptions()
        self.Document = Document()
        self.DocumentInfo = DocumentInfo()
        self.Documents = Documents()
        self.EPSOpenOptions = EPSOpenOptions()
        self.EPSSaveOptions = EPSSaveOptions()
        self.ExportOptionsIllustrator = ExportOptionsIllustrator()
        self.ExportOptionsSaveForWeb = ExportOptionsSaveForWeb()
        self.GalleryBannerOptions = GalleryBannerOptions()
        self.GalleryCustomColorOptions = GalleryCustomColorOptions()
        self.GalleryImagesOptions = GalleryImagesOptions()
        self.GalleryOptions = GalleryOptions()
        self.GallerySecurityOptions = GallerySecurityOptions()
        self.GalleryThumbnailOptions = GalleryThumbnailOptions()
        self.GIFSaveOptions = GIFSaveOptions()
        self.GrayColor = GrayColor()
        self.HistoryState = HistoryState()
        self.HistoryStates = HistoryStates()
        self.HSBColor = HSBColor()
        self.IndexedConversionOptions = IndexedConversionOptions()
        self.JPEGSaveOptions = JPEGSaveOptions()
        self.LabColor = LabColor()
        self.LayerComp = LayerComp()
        self.LayerComps = LayerComps()
        self.Layers = Layers()
        self.LayerSet = LayerSet()
        self.LayerSets = LayerSets()
        self.MeasurementLog = MeasurementLog()
        self.MeasurementScale = MeasurementScale()
        self.NoColor = NoColor()
        self.Notifier = Notifier()
        self.Notifiers = Notifiers()
        self.PathItem = PathItem()
        self.PathItems = PathItems()
        self.PathPoint = PathPoint()
        self.PathPointInfo = PathPointInfo()
        self.PathPoints = PathPoints()
        self.PDFOpenOptions = PDFOpenOptions()
        self.PDFSaveOptions = PDFSaveOptions()
        self.PhotoCDOpenOptions = PhotoCDOpenOptions()
        self.PhotoshopSaveOptions = PhotoshopSaveOptions()
        self.PICTFileSaveOptions = PICTFileSaveOptions()
        self.PicturePackageOptions = PicturePackageOptions()
        self.PixarSaveOptions = PixarSaveOptions()
        self.PNGSaveOptions = PNGSaveOptions()
        self.Preferences = Preferences()
        self.PresentationOptions = PresentationOptions()
        self.RawFormatOpenOptions = RawFormatOpenOptions()
        self.RawSaveOptions = RawSaveOptions()
        self.RGBColor = RGBColor()
        self.Selection = Selection()
        self.SGIRGBSaveOptions = SGIRGBSaveOptions()
        self.SolidColor = SolidColor()
        self.SubPathInfo = SubPathInfo()
        self.SubPathItem = SubPathItem()
        self.SubPathItems = SubPathItems()
        self.TargaSaveOptions = TargaSaveOptions()
        self.TextFont = TextFont()
        self.TextFonts = TextFonts()
        self.TextItem = TextItem()
        self.TiffSaveOptions = TiffSaveOptions()
        self.XMPMetadata = XMPMetadata()




from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pspalettetype import PsPaletteType
    from .application import Application
    from .psdithertype import PsDitherType
    from .psmattetype import PsMatteType
    from .psforcedcolors import PsForcedColors

class IndexedConversionOptions():
    """
    Options that can be specified when converting an RGB image to an indexed color model. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Colors(self) -> int:
        """
        Read-write. The number of palette colors. Note:Valid only when Palette = 2 (psMacOSPalette) 3 (psWindowsPalette) 4 (psWebPalette) 5 (psUniform) 6 (psLocalPerceptual) 7 (psLocalSelective) 8 (psLocalAdaptive) See Palette.
        """
        ...

    @property
    def Dither(self) -> PsDitherType:
        """
        Read-write. The dither type.
        """
        ...

    @property
    def DitherAmount(self) -> int:
        """
        Read-write. The amount of dither. (1 - 100). Note:Valid only when Dither = 2 (psDiffusion).
        """
        ...

    @property
    def Forced(self) -> PsForcedColors:
        """
        Read-write. The type of colors to force into the color palette.
        """
        ...

    @property
    def Matte(self) -> PsMatteType:
        """
        Read-write. Read-write. The color to use to fill antialiased edges adjacent to transparent areas of the image. Default: 4 (psWhiteMatte). Note:When Transparency = false, the matte color is applied to transparent areas. See Transparency.
        """
        ...

    @property
    def Palette(self) -> PsPaletteType:
        """
        Read-write. The palette type. Default: 1 (psExact).
        """
        ...

    @property
    def PreserveExactColors(self) -> bool:
        """
        Read-write.Indicates whether to protect colors in the image that contain entries in the color table from being dithered. Note:Valid only when Dither = 2. (psDiffusion) See Dither.
        """
        ...

    @property
    def Transparency(self) -> bool:
        """
        Read-write. Indicates whether to preserve transparent areas of the image during conversion to GIF format.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced IndexedConversionOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psbmpdepthtype import PsBMPDepthType
    from .psoperatingsystem import PsOperatingSystem

class BMPSaveOptions():
    """
    Options that can be specified when saving a document in BMP format. 
    """
    @property
    def AlphaChannels(self) -> bool:
        """
        Read-write. Indicates whether to save the alpha channels.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Depth(self) -> PsBMPDepthType:
        """
        Read-write. The number of bits per channel.
        """
        ...

    @property
    def FlipRowOrder(self) -> bool:
        """
        Read-write. Indicates whether to write the image from top to bottom. Default: false. Note:Available only when OSType = 2. See OSType.
        """
        ...

    @property
    def OSType(self) -> PsOperatingSystem:
        """
        Read-write. The target OS. Default: 2.
        """
        ...

    @property
    def RLECompression(self) -> bool:
        """
        Read-write. Indicates whether to use RLE compression. Note:Available only when OSType = 2. See OSType.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced BMPSaveOptions object.
        """
        ...

